@@ -91,7 +91,7 @@ setGeneric("bin_RLum.Data", function(object, ...) {
 #' temp.get <- get_RLum(object = temp1)
 #'
 #' @export
-setGeneric("get_RLum", function (object, ...) {
+setGeneric("get_RLum", function(object, ...) {
   standardGeneric("get_RLum")
 })
 
@@ -112,18 +112,21 @@ setMethod("get_RLum", signature = "list",
     function(object, class = NULL, null.rm = FALSE, ...) {
       ## take care of the class argument
       if (!is.null(class)) {
-        sel <- class[1] == vapply(object, function(x) class(x), character(1))
+        sel <- class[1] == vapply(object, function(x) class(x)[1], character(1))
         if (any(sel))
           object <- object[sel]
-
-        rm(sel)
       }
 
       ## make remove all non-RLum objects
       selection <- lapply(seq_along(object), function(x) {
         ## get rid of all objects that are not of type RLum, this is better
         ## than leaving that to the user
-        if (inherits(object[[x]], what = "RLum")) {
+        if (!inherits(object[[x]], what = "RLum")) {
+          warning("[get_RLum()] object #", x, " in the list is not of class ",
+                  "'RLum' and has been removed", call. = FALSE)
+          return(NULL)
+        }
+
           ## it might be the case the object already comes with empty objects,
           ## this would cause a crash
           if (inherits(object[[x]], "RLum.Analysis") &&
@@ -131,12 +134,6 @@ setMethod("get_RLum", signature = "list",
             return(NULL)
 
           get_RLum(object[[x]], ...)
-
-        } else {
-          warning(paste0("[get_RLum()] object #",x," in the list was not of type 'RLum' and has been removed!"),
-                  call. = FALSE)
-          return(NULL)
-        }
       })
 
       ## remove empty or NULL objects after the selection ... if wanted
@@ -219,7 +216,7 @@ setMethod("remove_RLum", signature = "list",
             })
 
             ## remove empty elements
-            tmp[vapply(tmp,length, numeric(1)) != 0]
+            tmp[lengths(tmp) > 0]
 })
 
 ## length_RLum() ------------------------------------------------------------
@@ -372,19 +369,19 @@ setMethod("melt_RLum", signature = "list",
 #'
 #' @rdname metadata
 #' @export
-setGeneric("add_metadata<-", function (object, ..., value) {
+setGeneric("add_metadata<-", function(object, ..., value) {
   standardGeneric("add_metadata<-")
 })
 
 #' @rdname metadata
 #' @export
-setGeneric("rename_metadata<-", function (object, ..., value) {
+setGeneric("rename_metadata<-", function(object, ..., value) {
   standardGeneric("rename_metadata<-")
 })
 
 #' @rdname metadata
 #' @export
-setGeneric("replace_metadata<-", function (object, ..., value) {
+setGeneric("replace_metadata<-", function(object, ..., value) {
   standardGeneric("replace_metadata<-")
 })
 
@@ -462,7 +459,7 @@ setMethod("names_RLum", signature = "list",
 #' @keywords utilities
 #'
 #' @export
-setGeneric("replicate_RLum", function (object, times = 1) {
+setGeneric("replicate_RLum", function(object, times = 1) {
    standardGeneric("replicate_RLum")
 })
 
@@ -560,12 +557,15 @@ setGeneric("set_Risoe.BINfileData", function(METADATA = data.frame(),
 #' plot_RLum(object)
 #'
 #' @export
-setGeneric("set_RLum", function (class, originator, .uid = create_UID(),
-                                 .pid = NA_character_, ... ) {
+setGeneric("set_RLum", function(class, originator, .uid = create_UID(),
+                                .pid = NA_character_, ... ) {
   .set_function_name("set_RLum")
   on.exit(.unset_function_name(), add = TRUE)
 
-  .validate_class(class, "character")
+  .validate_class(class, "character", length = 1)
+  if (!nzchar(class)) {
+    .throw_error("'class' cannot be an empty character")
+  }
   class(class) <- as.character(class)
 
   if (missing(originator)) {
@@ -800,7 +800,7 @@ setMethod("structure_RLum", signature = "list",
 #' @keywords utilities
 #'
 #' @export
-setGeneric("view", function (object, ... ) {
+setGeneric("view", function(object, ... ) {
   standardGeneric("view")
 })
 
