@@ -95,16 +95,21 @@ Risoe.BINfileData2RLum.Analysis<- function(
   .validate_class(object, "Risoe.BINfileData")
   .validate_class(pos, c("numeric", "integer"), null.ok = TRUE)
 
+  ## check that all required columns are available
+  sel.cols <- c("ID", "POSITION", "GRAIN", "RUN", "SET", "LTYPE", "DTYPE")
+  if (!all(sel.cols %in% colnames(object@METADATA))) {
+    .throw_error("'object' has missing columns in METADATA: ",
+                 .collapse(setdiff(sel.cols, colnames(object@METADATA))))
+  }
+
   positions.valid <- unique(object@METADATA[["POSITION"]])
   if (is.null(pos)) {
     pos <- positions.valid
-  } else {
+  } else if (length(setdiff(pos, positions.valid)) > 0) {
     ## remove invalid positions from the input
-    if (length(setdiff(pos, positions.valid)) > 0) {
       .throw_warning("Invalid position number skipped: ",
                      .collapse(setdiff(pos, positions.valid), quote = FALSE))
       pos <- intersect(pos, positions.valid)
-    }
   }
 
   # Grep run and set data ---------------------------------------------------
@@ -113,56 +118,46 @@ Risoe.BINfileData2RLum.Analysis<- function(
   grain.valid <- unique(object@METADATA[["GRAIN"]])
   if (is.null(grain)) {
     grain <- grain.valid
-  } else {
-      if(length(setdiff(grain, grain.valid)) > 0){
+  } else if (length(setdiff(grain, grain.valid)) > 0) {
         .throw_warning("Invalid grain number skipped: ",
                        .collapse(setdiff(grain, grain.valid), quote = FALSE))
         grain <- intersect(grain, grain.valid)
-      }
   }
 
   ## run
   run.valid <- unique(object@METADATA[["RUN"]])
   if (is.null(run)) {
     run <- run.valid
-  } else {
-    if (length(setdiff(run, run.valid)) > 0) {
+  } else if (length(setdiff(run, run.valid)) > 0) {
       .throw_error("'run' contains invalid runs, valid runs are: ",
                    .collapse(run.valid, quote = FALSE))
-    }
   }
 
   ## set
   set.valid <- unique(object@METADATA[["SET"]])
   if (is.null(set)) {
     set <- set.valid
-  } else {
-    if (length(setdiff(set, set.valid)) > 0) {
+  } else if (length(setdiff(set, set.valid)) > 0) {
       .throw_error("'set' contains invalid sets, valid sets are: ",
                    .collapse(set.valid, quote = FALSE))
-    }
   }
 
   ## ltype
   ltype.valid <- unique(object@METADATA[["LTYPE"]])
   if (is.null(ltype)) {
     ltype <- ltype.valid
-  } else {
-    if (length(setdiff(ltype, ltype.valid)) > 0) {
+  } else if (length(setdiff(ltype, ltype.valid)) > 0) {
       .throw_error("'ltype' contains invalid ltypes, valid ltypes are: ",
                    .collapse(ltype.valid, quote = TRUE))
-    }
   }
 
   ## dtype
   dtype.valid <- unique(object@METADATA[["DTYPE"]])
   if (is.null(dtype)) {
     dtype <- dtype.valid
-  } else {
-    if (length(setdiff(dtype, dtype.valid)) > 0) {
+  } else if (length(setdiff(dtype, dtype.valid)) > 0) {
       .throw_error("'dtype' contains invalid dtypes, valid dtypes are: ",
                    .collapse(dtype.valid, quote = TRUE))
-    }
   }
 
     # Select values and convert them-----------------------------------------------------------
@@ -182,28 +177,30 @@ Risoe.BINfileData2RLum.Analysis<- function(
       pb <- txtProgressBar(min=min(pos),max=max(pos), char="=", style=3)
     }
 
-    object <- lapply(pos, function(pos){
+  ## convert metadata object to data.table
+  metadata.dt <- as.data.table(object@METADATA[, sel.cols])
+
+  ## silence notes raised by R CMD check
+  POSITION <- GRAIN <- RUN <- SET <- LTYPE <- DTYPE <- ID <- NULL
+
+  object <- lapply(pos, function(pos) {
 
       ##update progress bar
       if(txtProgressBar){
         setTxtProgressBar(pb, value = pos)
       }
 
-      ##loop over the grains and produce RLum.Analysis objects
-      object <- lapply(grain, function(grain){
+    ## loop over the grains and produce RLum.Analysis objects
+    object <- lapply(grain, function(grain) {
 
         ## select data
         ## the NA check for grain is necessary as FI readers like to report
         ## NA instead of 0 in that column, and this causes some trouble
-        temp_id <- object@METADATA[
-              object@METADATA[["POSITION"]] == pos &
-              (is.na(object@METADATA[["GRAIN"]]) |
-               object@METADATA[["GRAIN"]] == grain) &
-              object@METADATA[["RUN"]] %in% run &
-              object@METADATA[["SET"]] %in% set &
-              object@METADATA[["LTYPE"]] %in% ltype &
-              object@METADATA[["DTYPE"]] %in% dtype
-            , "ID"]
+        temp_id <- metadata.dt[POSITION == pos &
+                               (is.na(GRAIN) | GRAIN == grain) &
+                               RUN %in% run & LTYPE %in% ltype &
+                               SET %in% set & DTYPE %in% dtype,
+                               ID]
 
         ## if the input object is empty, bypass the creation of curve objects
         if (length(object@DATA) == 0) {
