@@ -8,9 +8,10 @@
 #' Kars et al. (2008).
 #'
 #' @details
-#' All provided output corresponds to the \eqn{tc} value obtained by this analysis. Additionally
-#' in the output object the g-value normalised to 2-days is provided. The output of this function
-#' can be passed to the function [calc_FadingCorr].
+#' All provided output corresponds to the \eqn{tc} value obtained by this
+#' analysis. Additionally, the g-value normalised to 2-days is provided in the
+#' output object. The output of this function can be passed to the function
+#' [calc_FadingCorr].
 #'
 #' **Fitting and error estimation**
 #'
@@ -49,49 +50,54 @@
 #'
 #' **Multiple aliquots & Lx/Tx normalisation**
 #'
-#' Be aware that this function will always normalise all \eqn{\frac{L_x}{T_x}} values
-#' by the \eqn{\frac{L_x}{T_x}} value of the
-#' prompt measurement of the first aliquot. This implicitly assumes that there are no systematic
+#' Be aware that this function will always normalise all \eqn{\frac{L_x}{T_x}}
+#' values by the \eqn{\frac{L_x}{T_x}} value of the prompt measurement of the
+#' first aliquot. This implicitly assumes that there are no systematic
 #' inter-aliquot variations in the \eqn{\frac{L_x}{T_x}} values.
 #' If deemed necessary to normalise the \eqn{\frac{L_x}{T_x}} values  of each
 #' aliquot by its individual prompt measurement please do so **before** running
-#' [analyse_FadingMeasurement] and provide the already normalised values for `object` instead.
+#' [analyse_FadingMeasurement] and provide the already normalised values for
+#' `object` instead.
 #'
 #' **Shine-down curve plots**
 #' Please note that the shine-down curve plots are for information only. As such
 #' a maximum of five pause steps are plotted to avoid graphically overloaded plots.
 #' However, *all* pause times are taken into consideration for the analysis.
 #'
-#' @param object [RLum.Analysis-class] (**required**):
-#' input object with the measurement data. Alternatively, a [list] containing [RLum.Analysis-class]
-#' objects or a [data.frame] with three columns
+#' @param object [RLum.Analysis-class], [data.frame] or [list] (**required**):
+#' input object with the measurement data. Alternatively, a [list] containing
+#' [RLum.Analysis-class] objects or a [data.frame] with three columns
 #' (x = LxTx, y = LxTx error, z = time since irradiation) can be provided.
-#' Can also be a wide table, i.e. a [data.frame] with a number of columns divisible by 3
-#' and where each triplet has the before mentioned column structure.
+#' Can also be a wide table, i.e. a [data.frame] with a number of columns
+#' divisible by 3 and where each triplet has the before mentioned column
+#' structure.
 #'
 #' **Please note: The input object should solely consists of the curve needed
 #' for the data analysis, i.e. only IRSL curves representing Lx (and Tx). If
 #' the object originated from an XSYG file, also the irradiation steps must
 #' be preserved in the input object.**
 #'
-#' If data from multiple aliquots are provided please **see the details below** with regard to
-#' Lx/Tx normalisation. **The function assumes that all your measurements are related to
-#' one (comparable) sample. If you have to treat independent samples, you have use this function
-#' in a loop.**
+#' If data from multiple aliquots are provided please **see the details below**
+#' with regard to Lx/Tx normalisation. **The function assumes that all your
+#' measurements are related to one (comparable) sample. If you have to treat
+#' independent samples, you have use this function in a loop.**
 #'
 #' @param structure [character] (*with default*):
 #' the structure of the measurement data, one of `'Lx'` or `c('Lx','Tx')`.
 #'
-#' @param signal.integral [vector] (**required**): vector with channels for the signal integral
-#' (e.g., `c(1:10)`). Not required if a `data.frame` with `LxTx` values is provided.
+#' @param signal.integral [vector] (**required**):
+#' vector with channels for the signal integral (e.g., `1:10`). It is not
+#' required if a `data.frame` with `LxTx` values is provided.
 #'
-#' @param background.integral [vector] (**required**): vector with channels for the background integral
-#' (e.g., `c(90:100)`). Not required if a `data.frame` with `LxTx` values is provided.
+#' @param background.integral [vector] (**required**):
+#' vector with channels for the background integral (e.g., `90:100`). It is not
+#' required if a `data.frame` with `LxTx` values is provided.
 #'
-#' @param t_star [character] (*with default*):
-#' method for calculating the time elapsed since irradiation if input is **not** a `data.frame`.
-#' Options are: `'half'` (the default), `'half_complex`, which uses the long equation in Auclair et al. 2003, and
-#' and `'end'`, which takes the time between irradiation and the measurement step.
+#' @param t_star [character], [function] (*with default*):
+#' method for calculating the time elapsed since irradiation if input is
+#' **not** a `data.frame`. Options are: `'half'` (the default), `'half_complex`,
+#' which uses the long equation in Auclair et al. 2003, and `'end'`, which
+#' takes the time between irradiation and the measurement step.
 #' Alternatively, `t_star` can be a function with one parameter which works on `t1`.
 #' For more information see details. \cr
 #'
@@ -107,17 +113,17 @@
 #' @param plot [logical] (*with default*):
 #' enable/disable the plot output.
 #'
-#' @param plot_singlePanels [logical] (*with default*) or [numeric] (*optional*):
+#' @param plot_singlePanels [logical] or [numeric] (*with default*):
 #' enable/disable single plot mode, i.e. one plot window per plot.
 #' Alternatively a vector specifying the plot to be drawn, e.g.,
 #' `plot_singlePanels = c(3,4)` draws only the last two plots in separate
 #' windows.
 #'
-#' @param ... (*optional*) further arguments that can be passed to internally used functions. Supported arguments:
-#' `xlab`, `log`, `mtext`, `plot.trend` (enable/disable trend blue line), and `xlim` for the
-#' two first curve plots, and `ylim` for the fading
-#' curve plot. For further plot customization please use the numerical output of the functions for
-#' own plots.
+#' @param ... further arguments that can be passed to internally used functions.
+#' Supported arguments: `xlab`, `log`, `mtext`, `plot.trend` (enable/disable
+#' trend blue line), and `xlim` for the two first curve plots, and `ylim` for
+#' the fading curve plot. For further plot customization please use the
+#' numerical output of the functions for own plots.
 #'
 #' @return
 #' An [RLum.Results-class] object is returned:
@@ -140,7 +146,7 @@
 #' `call` \tab `call` \tab the original function call\cr
 #' }
 #'
-#' @section Function version: 0.1.23
+#' @section Function version: 0.1.25
 #'
 #' @author Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany) \cr
 #' Christoph Burow, University of Cologne (Germany)
@@ -192,8 +198,8 @@
 analyse_FadingMeasurement <- function(
   object,
   structure = c("Lx", "Tx"),
-  signal.integral,
-  background.integral,
+  signal.integral = NULL,
+  background.integral = NULL,
   t_star = 'half',
   n.MC = 100,
   verbose = TRUE,
@@ -208,14 +214,15 @@ analyse_FadingMeasurement <- function(
   .validate_class(object, c("RLum.Analysis", "data.frame", "list"))
   .validate_class(structure, "character")
   .validate_class(plot_singlePanels, c("logical", "integer", "numeric"))
+  .validate_positive_scalar(n.MC, int = TRUE)
 
   if (inherits(object, "list")) {
-    wrong.class <- sapply(object, class) != "RLum.Analysis"
+    wrong.class <- !sapply(object, inherits, "RLum.Analysis")
     if (any(wrong.class)) {
       .throw_warning(sum(wrong.class), " unsupported records removed")
 
       ## remove unwanted stuff
-      object[wrong.class] <- NULL
+      object <- object[!wrong.class]
       if (length(object) == 0) {
         .throw_error("No valid records in 'object' left")
       }
@@ -226,23 +233,21 @@ analyse_FadingMeasurement <- function(
   } else if(inherits(object,"data.frame")){
     .validate_not_empty(object)
     if (ncol(object) %% 3 != 0) {
-      .throw_error("'object': if you provide a data.frame as input, ",
-                   "the number of columns must be a multiple of 3.")
-    } else {
-      object <- do.call(rbind,
-                        lapply(seq(1, ncol(object), 3), function(col) {
-                          setNames(object[ , col:c(col+2)], c("LxTx", "LxTxError", "timeSinceIrr"))
-                          })
-                        )
+      .throw_error("When 'object' is a data.frame, the number of columns ",
+                   "must be a multiple of 3")
+    }
+    colnames(object) <- NULL
+    object <- do.call(rbind,
+                      lapply(seq(1, ncol(object), 3), function(col) {
+                        object[, col + 0:2]
+                      }))
       object <- object[stats::complete.cases(object), ]
       if (nrow(object) == 0)
         .throw_error("After NA removal, nothing is left from the data set")
-    }
 
     ##set table and object
     LxTx_table <- data.frame(LxTx = object[[1]], LxTx.Error = object[[2]])
-    TIMESINCEIRR <- object[[3]]
-    irradiation_times <- TIMESINCEIRR
+    irradiation_times <- TIMESINCEIRR <- object[[3]]
     object <- NULL
   }
 
@@ -253,8 +258,6 @@ analyse_FadingMeasurement <- function(
 
   # Prepare data --------------------------------------------------------------------------------
   if(!is.null(object)){
-    originators <- unique(unlist(lapply(object, slot, name = "originator")))
-
     if (!(length(structure) == 1 && structure == "Lx" ||
           length(structure) == 2 && all(structure == c("Lx", "Tx")))) {
       .throw_message("'structure' can only be 'Lx' or c('Lx', 'Tx'), ",
@@ -263,7 +266,15 @@ analyse_FadingMeasurement <- function(
     }
 
     ## support read_XSYG2R()
-    if (length(originators) == 1 && originators == "read_XSYG2R") {
+    originator <- unique(unlist(lapply(object, slot, name = "originator")))
+    if (length(originator) != 1 ||
+        !originator %in% c("read_XSYG2R", "read_BIN2R",
+                           "Risoe.BINfileData2RLum.Analysis"))  {
+      .throw_message("Unknown or unsupported originator, NULL returned")
+      return(NULL)
+    }
+
+    if (originator == "read_XSYG2R") {
       ## extract irradiation times
       irradiation_times <- extract_IrradiationTimes(object)
 
@@ -296,8 +307,7 @@ analyse_FadingMeasurement <- function(
       }
 
       ##support read_BIN2R()
-    } else if (length(originators) == 1 &&
-               originators %in% c("read_BIN2R", "Risoe.BINfileData2RLum.Analysis")) {
+    } else if (originator %in% c("read_BIN2R", "Risoe.BINfileData2RLum.Analysis")) {
 
       ##assign object, unlist and drop it
       object_clean <- unlist(get_RLum(object))
@@ -314,24 +324,18 @@ analyse_FadingMeasurement <- function(
 
       ##check whether we have negative irradiation times, sort out such values
       if(any(TIMESINCEIRR < 0)){
-        #count affected records
-        rm_records <- sum(TIMESINCEIRR < 0)
-
         ##now we have a problem and we first have to make sure that we understand
         ##the data structure and remove also the corresponding values
         if(all(structure == c("Lx", "Tx"))){
           rm_id <- matrix(TIMESINCEIRR, ncol = 2, byrow = TRUE)
           rm_id[apply(rm_id < 0, MARGIN = 1, any),] <- NA
-          rm_id <- which(is.na(as.numeric(t(rm_id))))
-          object_clean[rm_id] <- NULL
-          TIMESINCEIRR <- TIMESINCEIRR[-rm_id]
-          rm_records <- length(rm_id)
-          rm(rm_id)
-
+          rm_id <- is.na(as.numeric(t(rm_id)))
         }else{
-          object_clean[TIMESINCEIRR < 0] <- NULL
-          TIMESINCEIRR <- TIMESINCEIRR[!TIMESINCEIRR < 0]
+          rm_id <- TIMESINCEIRR < 0
         }
+        object_clean[rm_id] <- NULL
+        TIMESINCEIRR <- TIMESINCEIRR[!rm_id]
+        rm_records <- sum(rm_id)
 
         .throw_warning("removed ", rm_records, " records with negative ",
                        "'time since irradiation'")
@@ -348,10 +352,6 @@ analyse_FadingMeasurement <- function(
       irradiation_times <- vapply(object_clean, function(o){
         o@info$IRR_TIME
       }, numeric(1))
-
-    }else{
-      .throw_message("Unknown or unsupported originator, NULL returned")
-      return(NULL)
     }
 
     ##correct irradiation time for t_star
@@ -364,23 +364,25 @@ analyse_FadingMeasurement <- function(
     ## set t_star ----
     if (inherits(t_star, "function")) {
       t_star <- t_star(t1)
-
     } else {
-      if(t_star == "half"){
-        ##calculate t_star using the simplified equation in Auclair et al. (2003)
-        t_star <- t1 + (t2 - t1)/2
+      t_star <- switch(
+          t_star,
 
-      } else if(t_star == "half_complex"){
-        # calculate t_star after the full equation Auclair et al. (2003)
-        # t0 is an arbitrary constant, we are setting that to 1
-        t0 <- 1
-        t_star <- t0 * 10^((t2 * log10(t2/t0) - t1 * log10(t1/t0) - (t2 - t1) * log10(exp(1))) /
-                     (t2 - t1))
+          ## use the simplified equation in Auclair et al. (2003)
+          half = t1 + (t2 - t1) / 2,
 
-      }else if (t_star == "end"){
-        ##set t_start as t_1 (so after the end of irradiation)
-        t_star <- t1
-      }
+          ## use full equation Auclair et al. (2003)
+          ## t0 is an arbitrary constant, we are setting that to 1
+          half_complex = {
+            t0 <- 1
+            t_star <- t0 * 10^((t2 * log10(t2/t0) -
+                                t1 * log10(t1/t0) -
+                                (t2 - t1) * log10(exp(1))) / (t2 - t1))
+          },
+
+          ## set t_star to t_1 (so after the end of irradiation)
+          end = t1
+      )
     }
 
     ##overwrite TIMESINCEIRR
@@ -468,6 +470,9 @@ analyse_FadingMeasurement <- function(
   idx.tc <- which(TIMESINCEIRR == tc)[1]
   if (length(structure) == 2 || is.null(object)){
     LxTx <- LxTx_table[["LxTx"]]
+    if (LxTx[idx.tc] <= 0) {
+      .throw_error("Normalisation term is not positive, check your input")
+    }
     LxTx_NORM <- LxTx / LxTx[idx.tc]
     LxTx_NORM.ERROR <- LxTx_table[["LxTx.Error"]] / LxTx[idx.tc]
   } else {
@@ -491,10 +496,9 @@ analyse_FadingMeasurement <- function(
       UID = uid
     )
 
-
   # Fitting -------------------------------------------------------------------------------------
   ## prevent that n.MC can become smaller than 2
-  n.MC <- max(c(n.MC[1],2))
+  n.MC <- max(n.MC, 2)
 
   ##we need to fit the data to get the g_value
 
@@ -508,11 +512,11 @@ analyse_FadingMeasurement <- function(
                      ncol = n.MC)))
 
   ##apply the fit
-  fit_matrix <- vapply(X = 2:(n.MC+1), FUN = function(x){
+  fit_matrix <- vapply(X = 1:n.MC, FUN = function(x) {
     ##fit
     fit <- try(stats::lm(y ~ x, data = data.frame(
       x = MC_matrix[,1],
-      y = MC_matrix[,x]))$coefficients, silent = TRUE)
+      y = MC_matrix[, x + 1]))$coefficients, silent = TRUE)
 
     if (inherits(fit, "try-error"))
       return(c(NA_real_, NA_real_))
@@ -534,7 +538,6 @@ analyse_FadingMeasurement <- function(
     sd = abs(LxTx_table[["LxTx_NORM.ERROR"]])
   ), ncol = n.MC))
 
-
   ## calculate rho prime for all MC samples
   fit_vector_rhop <- suppressWarnings(apply(MC_matrix_rhop, MARGIN = 2, FUN = function(x) {
     tryCatch({
@@ -550,27 +553,26 @@ analyse_FadingMeasurement <- function(
   ## discard all NA values produced in MC runs
   fit_vector_rhop <- fit_vector_rhop[!is.na(fit_vector_rhop)]
 
+  .collect_results <- function(val, vals.MC) {
+    data.frame(FIT = val,
+               MEAN = mean(vals.MC),
+               SD = sd(vals.MC),
+               Q_0.025 = quantile(vals.MC, probs = 0.025, na.rm = TRUE),
+               Q_0.16  = quantile(vals.MC, probs = 0.16,  na.rm = TRUE),
+               Q_0.84  = quantile(vals.MC, probs = 0.84,  na.rm = TRUE),
+               Q_0.975 = quantile(vals.MC, probs = 0.975, na.rm = TRUE),
+               row.names = NULL)
+  }
+
   ## calculate mean and standard deviation of rho prime (in log10 space)
-  rhoPrime <- data.frame(
-    MEAN = mean(fit_vector_rhop),
-    SD = sd(fit_vector_rhop),
-    Q_0.025 = quantile(x = fit_vector_rhop, probs = 0.025, na.rm = TRUE),
-    Q_0.16 = quantile(x = fit_vector_rhop, probs = 0.16, na.rm = TRUE),
-    Q_0.84 = quantile(x = fit_vector_rhop, probs = 0.84, na.rm = TRUE),
-    Q_0.975 = quantile(x = fit_vector_rhop, probs = 0.975, na.rm = TRUE),
-    row.names = NULL
-  )
+  rhoPrime <- .collect_results(mean(fit_vector_rhop), fit_vector_rhop)
 
   ## calc g-value -----
-  fit <-
-    try(stats::lm(y ~ x,
-              data = data.frame(x = LxTx_table[["TIMESINCEIRR_NORM.LOG"]],
-                                y = LxTx_table[["LxTx_NORM"]])), silent = TRUE)
-
-
-  fit_power <- try(stats::lm(y ~ I(x^3) + I(x^2) + I(x) ,
-                         data = data.frame(x = LxTx_table[["TIMESINCEIRR_NORM.LOG"]],
-                                           y = LxTx_table[["LxTx_NORM"]])), silent = TRUE)
+  df <- data.frame(x = LxTx_table[["TIMESINCEIRR_NORM.LOG"]],
+                   y = LxTx_table[["LxTx_NORM"]])
+  fit <- try(stats::lm(y ~ x, data = df), silent = TRUE)
+  fit_power <- try(stats::lm(y ~ I(x^3) + I(x^2) + I(x),
+                             data = df), silent = TRUE)
 
   ##for predicting
   fit_predict <-
@@ -585,15 +587,7 @@ analyse_FadingMeasurement <- function(
   }
 
   ##construct output data.frame
-  g_value <- data.frame(
-    FIT =  g_value_fit,
-    MEAN = mean(g_value.MC),
-    SD = sd(g_value.MC),
-    Q_0.025 = quantile(x = g_value.MC, probs = 0.025, na.rm = TRUE),
-    Q_0.16 = quantile(x = g_value.MC, probs = 0.16, na.rm = TRUE),
-    Q_0.84 = quantile(x = g_value.MC, probs = 0.84, na.rm = TRUE),
-    Q_0.975 = quantile(x = g_value.MC, probs = 0.975, na.rm = TRUE)
-  )
+  g_value <- .collect_results(g_value_fit, g_value.MC)
 
   ##normalise the g-value to 2-days using the equation provided by Sébastien Huot via e-mail
   ##this means the data is extended
@@ -633,12 +627,10 @@ analyse_FadingMeasurement <- function(
     )
   }
 
-
   ## Plotting ---------------------------------------------------------------
   if(plot) {
-
     ## deprecated argument
-    if ("plot.single" %in% names(list(...))) {
+    if ("plot.single" %in% ...names()) {
       plot_singlePanels <- list(...)$plot.single
       .throw_warning("'plot.single' is deprecated, use 'plot_singlePanels' ",
                      "instead")
@@ -646,8 +638,8 @@ analyse_FadingMeasurement <- function(
 
     ## split the plot area into 4 regions if plot_singlePanels = FALSE (default)
     if (is.logical(plot_singlePanels) && !plot_singlePanels[1]) {
-      par.default <- par()$mfrow
-      on.exit(par(mfrow = par.default), add = TRUE)
+      par.default <- .par_defaults()
+      on.exit(par(par.default), add = TRUE)
       par(mfrow = c(2, 2))
     }
 
@@ -682,161 +674,75 @@ analyse_FadingMeasurement <- function(
     if (is.logical(plot_singlePanels))
       plot_singlePanels <- 1:4
 
-    ## plot Lx-curves -----
+    ## compute integration limits for plots
     if (!is.null(object)) {
       if (length(structure) == 2) {
-
-        if (1 %in% plot_singlePanels) {
-          records <- object_clean[seq(1, length(object_clean), by = 2)]
-          plot_RLum(
-            set_RLum(class = "RLum.Analysis",
-                     records = records),
-            combine = length(records) > 1,
-            col = c(col[1:5], rep(
-              rgb(0, 0, 0, 0.3), abs(length(TIMESINCEIRR) - 5)
-            ))[1:length(records)],
-            records_max = 10,
-            plot_singlePanels = TRUE,
-            legend.text = c(paste(round(irradiation_times.unique, 1), "s")),
-            xlab = plot_settings$xlab,
-            xlim = plot_settings$xlim,
-            log = plot_settings$log,
-            legend.pos = "outside",
-            main = bquote(L[x] ~ "- curve"),
-            mtext = plot_settings$mtext
-          )
-
-          ##add integration limits
-          abline(v = c(
-            object_clean[[1]][range(signal.integral), 1],
-            object_clean[[1]][range(background.integral), 1]),
-            lty = c(2,2,2,2),
-            col = c("green", "green", "red", "red"))
-        }
-
-        # plot Tx-curves ----
-        if (2 %in% plot_singlePanels) {
-          records <- object_clean[seq(2, length(object_clean), by = 2)]
-          plot_RLum(
-            set_RLum(class = "RLum.Analysis",
-                     records = records),
-            combine = length(records) > 1,
-            records_max = 10,
-            plot_singlePanels = TRUE,
-            legend.text = paste(round(irradiation_times.unique, 1), "s"),
-            xlab = plot_settings$xlab,
-            log = plot_settings$log,
-            legend.pos = "outside",
-            main = bquote(T[x] ~ "- curve"),
-            mtext = plot_settings$mtext
-          )
-
-          if (is.null(list(...)$signal.integral.Tx)) {
-            ##add integration limits
-            abline(v = c(
-              object_clean[[1]][range(signal.integral), 1],
-              object_clean[[1]][range(background.integral), 1]),
-              lty = c(2,2,2,2),
-              col = c("green", "green", "red", "red"))
-
-          } else{
-            ##add integration limits
-            abline(
-              v = range(list(...)$signal.integral.Tx) *
-                max(as.matrix(object_clean[[1]][, 1])) /
-                nrow(as.matrix(object_clean[[1]])),
-              lty = 2,
-              col = "green"
-            )
-            abline(
-              v = range(list(...)$background.integral.Tx) *
-                max(as.matrix(object_clean[[1]][, 1])) /
-                nrow(as.matrix(object_clean[[1]])),
-              lty = 2,
-              col = "red"
-            )
-          }
-        }
-
-      } else{
-        if (1 %in% plot_singlePanels) {
-          plot_RLum(
-            set_RLum(class = "RLum.Analysis", records = object_clean),
-            combine = length(object_clean) > 1,
-            records_max = 10,
-            plot_singlePanels = TRUE,
-            legend.text = c(paste(round(irradiation_times.unique, 1), "s")),
-            legend.pos = "outside",
-            xlab = plot_settings$xlab,
-            log = plot_settings$log,
-            main = bquote(L[x] ~ " - curves"),
-            mtext = plot_settings$mtext
-          )
-
-          ##add integration limits
-          abline(
-            v = range(signal.integral) * max(as.matrix(object_clean[[1]][, 1])) /
-              nrow(as.matrix(object_clean[[1]])),
-            lty = 2,
-            col = "green"
-          )
-          abline(
-            v = range(background.integral) * max(as.matrix(object_clean[[1]][, 1])) /
-              nrow(as.matrix(object_clean[[1]])),
-            lty = 2,
-            col = "red"
-          )
-        }
-
-        ##empty Tx plot
-        if (2 %in% plot_singlePanels) {
-          plot(
-            NA,
-            NA,
-            xlim = c(0, 1),
-            ylim = c(0, 1),
-            xlab = "",
-            ylab = "",
-            axes = FALSE
-          )
-          text(x = 0.5,
-               y = 0.5,
-               labels = expression(paste("No ", T[x], " curves detected")))
-        }
+        int.limits.lx <- c(object_clean[[1]][range(signal.integral), 1],
+                           object_clean[[1]][range(background.integral), 1])
+      } else {
+        int.limits.lx <- c(range(signal.integral), range(background.integral)) *
+          max(as.matrix(object_clean[[1]][, 1])) /
+          nrow(as.matrix(object_clean[[1]]))
       }
-
-    }else{
-      if (1 %in% plot_singlePanels) {
-        ##empty Lx plot
-        plot(
-          NA,
-          NA,
-          xlim = c(0, 1),
-          ylim = c(0, 1),
-          xlab = "",
-          ylab = "",
-          axes = FALSE
-        )
-        text(x = 0.5,
-             y = 0.5,
-             labels = expression(paste("No ", L[x], " curves detected")))
+      if (is.null(list(...)$signal.integral.Tx)) {
+        int.limits.tx <- int.limits.lx
+      } else {
+        int.limits.tx <- c(range(list(...)$signal.integral.Tx),
+                           range(list(...)$background.integral.Tx)) *
+          max(as.matrix(object_clean[[1]][, 1])) /
+          nrow(as.matrix(object_clean[[1]]))
       }
+    }
 
-      if (2 %in% plot_singlePanels) {
-        ##empty Tx plot
-        plot(
-          NA,
-          NA,
-          xlim = c(0, 1),
-          ylim = c(0, 1),
-          xlab = "",
-          ylab = "",
-          axes = FALSE
-        )
-        text(x = 0.5,
-             y = 0.5,
-             labels = expression(paste("No ", T[x], " curves detected")))
-      }
+    ## plot Lx-curves -----
+    if (!is.null(object) && 1 %in% plot_singlePanels) {
+      records <- object_clean[seq(1, length(object_clean), by = length(structure))]
+      plot_RLum(
+          set_RLum(class = "RLum.Analysis",
+                   records = records),
+          combine = length(records) > 1,
+          records_max = 10,
+          plot_singlePanels = TRUE,
+          legend.text = c(paste(round(irradiation_times.unique, 1), "s")),
+          xlab = plot_settings$xlab,
+          xlim = plot_settings$xlim,
+          log = plot_settings$log,
+          legend.pos = "outside",
+          main = bquote(L[x] ~ "- curve"),
+          mtext = plot_settings$mtext
+      )
+      abline(v = int.limits.lx, lty = 2,
+             col = c("green", "green", "red", "red"))
+    } else if (1 %in% plot_singlePanels) {
+      ## empty Lx plot
+      shape::emptyplot()
+      text(x = 0.5, y = 0.5,
+           labels = expression(paste("No ", L[x], " curves detected")))
+    }
+
+    ## plot Tx-curves ----
+    if (!is.null(object) && length(structure) == 2 && 2 %in% plot_singlePanels) {
+      records <- object_clean[seq(2, length(object_clean), by = 2)]
+      plot_RLum(
+          set_RLum(class = "RLum.Analysis",
+                   records = records),
+          combine = length(records) > 1,
+          records_max = 10,
+          plot_singlePanels = TRUE,
+          legend.text = paste(round(irradiation_times.unique, 1), "s"),
+          xlab = plot_settings$xlab,
+          log = plot_settings$log,
+          legend.pos = "outside",
+          main = bquote(T[x] ~ "- curve"),
+          mtext = plot_settings$mtext
+      )
+      abline(v = int.limits.tx, lty = 2,
+             col = c("green", "green", "red", "red"))
+    } else if (2 %in% plot_singlePanels) {
+      ## empty Tx plot
+      shape::emptyplot()
+      text(x = 0.5, y = 0.5,
+           labels = expression(paste("No ", T[x], " curves detected")))
     }
 
     ## plot fading ----
@@ -846,7 +752,7 @@ analyse_FadingMeasurement <- function(
         ## FIXME(mcol): this block seems unreachable since 5f63c1f1
         # nocov start
           shape::emptyplot()
-          text(x = .5, y = .5, labels = "All NA values!")
+          text(x = 0.5, y = 0.5, labels = "All NA values!")
         # nocov end
       }else{
         plot(
@@ -856,13 +762,13 @@ analyse_FadingMeasurement <- function(
           xaxt = "n",
           xlab = "Time since irradition [s]",
           sub = expression(paste("[", log[10](t / t[c]), "]")),
-          ylim = plot_settings$ylim %||% {
+          ylim = plot_settings$ylim %||% (
             if (max(LxTx_table[["LxTx_NORM"]]) > 1.1) {
               c(0.1, max(LxTx_table[["LxTx_NORM"]]) + max(LxTx_table[["LxTx_NORM.ERROR"]]))
             } else {
               c(0.1, 1.1)
             }
-          },
+          ),
           xlim = range(LxTx_table[["TIMESINCEIRR_NORM.LOG"]], na.rm = TRUE),
           main = "Signal Fading"
         )
@@ -986,7 +892,7 @@ analyse_FadingMeasurement <- function(
 
       if(all(is.na(g_value.MC))){
         shape::emptyplot()
-        text(x = .5, y = .5, labels = "All NA values!")
+        text(x = 0.5, y = 0.5, labels = "All NA values!")
 
       }else{
         plot(density(g_value.MC),
@@ -1064,7 +970,7 @@ analyse_FadingMeasurement <- function(
   }
 
   ##return
-  return(set_RLum(
+  set_RLum(
     class = "RLum.Results",
     data = list(
       fading_results = fading_results,
@@ -1074,5 +980,5 @@ analyse_FadingMeasurement <- function(
       irr.times = irradiation_times
     ),
     info = list(call = sys.call())
-  ))
+  )
 }
