@@ -1,46 +1,53 @@
 #' @title Bayesian models (baSAR) applied on luminescence data
 #'
-#' @description This function allows the application of Bayesian models on luminescence data, measured
-#' with the single-aliquot regenerative-dose (SAR, Murray and Wintle, 2000) protocol. In particular,
-#' it follows the idea proposed by Combès et al., 2015 of using an hierarchical model for estimating
-#' a central equivalent dose from a set of luminescence measurements. This function is (I) the adoption
-#' of this approach for the R environment and (II) an extension and a technical refinement of the
-#' published code.
+#' @description
+#' This function allows the application of Bayesian models on luminescence data
+#' measured with the single-aliquot regenerative-dose (SAR, Murray and Wintle,
+#' 2000) protocol. In particular, it follows the idea proposed by Combès et al.,
+#' 2015 of using an hierarchical model for estimating a central equivalent dose
+#' from a set of luminescence measurements. This function (I) implements this
+#' approach for the R environment and (II) provides an extension and a technical
+#' refinement of the published code.
 #'
 #' @details
-#' Internally the function consists of two parts: (I) The Bayesian core for the Bayesian calculations
-#' and applying the hierarchical model and (II) a data pre-processing part. The Bayesian core can be run
-#' independently, if the input data are sufficient (see below). The data pre-processing part was
-#' implemented to simplify the analysis for the user as all needed data pre-processing is done
-#' by the function, i.e. in theory it is enough to provide a BIN/BINX-file with the SAR measurement
-#' data. For the Bayesian analysis for each aliquot the following information are needed from the SAR analysis.
-#' `LxTx`, the `LxTx` error and the dose values for all regeneration points.
+#' Internally the function consists of two parts: (I) a Bayesian core that
+#' performs the hierarchical modelling and calculations, and (II) a data
+#' pre-processing stage. The Bayesian core can be run independently if sufficient
+#' input data are provided (see below). The data pre-processing stage exists
+#' to simplify the user workflow by preparing all required inputs; in principle
+#' it is enough to provide a BIN/BINX-file with the SAR measurement data. For
+#' the Bayesian analysis for each aliquot the following information are needed
+#' from the SAR analysis: `LxTx`, the `LxTx` error and the dose values for all
+#' regeneration points.
 #'
 #' **How is the systematic error contribution calculated?**
 #'
-#' Standard errors (so far) provided with the source dose rate are considered as systematic uncertainties
-#' and added to final central dose by:
+#' Standard errors (so far) provided with the source dose rate are considered
+#' as systematic uncertainties and added to final central dose by:
 #'
 #' \deqn{systematic.error = 1/n \sum SE(source.doserate)}
 #'
 #' \deqn{SE(central.dose.final) = \sqrt{SE(central.dose)^2 + systematic.error^2}}
 #'
-#' Please note that this approach is rather rough and can only be valid if the source dose rate
-#' errors, in case different readers had been used, are similar. In cases where more than
-#' one source dose rate is provided a warning is given.
+#' Please note that this approach is rather rough and can only be valid if the
+#' source dose rate errors, in case different readers had been used, are
+#' similar. In cases where more than one source dose rate is provided a
+#' warning is given.
 #'
 #' **Input / output scenarios**
 #'
-#' Various inputs are allowed for this function. Unfortunately this makes the function handling rather
-#' complex, but at the same time very powerful. Available scenarios:
+#' Various inputs are allowed for this function. Unfortunately this makes the
+#' function handling rather complex, but at the same time very powerful.
+#' Available scenarios:
 #'
 #' **(1) - `object` is BIN-file or link to a BIN-file**
 #'
-#' Finally it does not matter how the information of the BIN/BINX file are provided. The function
-#' supports **(a)** either a path to a file or directory or a `list` of file names or paths or
-#' **(b)** a [Risoe.BINfileData-class] object or a list of these objects. The latter one can
-#' be produced by using the function [read_BIN2R], but this function is called automatically
-#' if only a file name and/or a path is provided. In both cases it will become the data that can be
+#' It does not matter how the information of the BIN/BINX file are provided.
+#' The function supports **(a)** either a path to a file or directory or a
+#' `list` of file names or paths or  **(b)** a [Risoe.BINfileData-class] object
+#' or a list of these objects. The latter one can be produced by using function
+#' [read_BIN2R], but this function is called automatically if only a file name
+#' and/or a path is provided. In both cases it will become the data that can be
 #' used for the analysis.
 #'
 #' `[CSV_file = NULL]`
@@ -63,9 +70,8 @@
 #'  2. Calculate De values using the function [plot_GrowthCurve]
 #'
 #' The CSV file should contain the BIN-file names and the aliquots selected
-#' for the further analysis. This allows a manual selection of input data, as the automatic selection
-#' by [verify_SingleGrainData] might be not totally sufficient.
-#'
+#' for the further analysis. This allows a manual selection of input data, as
+#' the automatic selection by [verify_SingleGrainData] might not be sufficient.
 #'
 #' **(2) - `object` `RLum.Results object`**
 #'
@@ -317,11 +323,10 @@
 #'
 #' **Please note: If distribution was set to `log_normal` the central dose is given as geometric mean!**
 #'
-#'
-#' @section Function version: 0.1.36
+#' @section Function version: 0.1.37
 #'
 #' @author
-#' Norbert Mercier, Archaésciences Bordeaux, CNRS-Université Bordeaux Montaigne (France) \cr
+#' Norbert Mercier, Archéosciences Bordeaux, CNRS-Université Bordeaux Montaigne (France) \cr
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany) \cr
 #' The underlying Bayesian model based on a contribution by Combès et al., 2015.
 #'
@@ -331,11 +336,11 @@
 #'
 #' @references
 #'
-#' Combès, B., Philippe, A., Lanos, P., Mercier, N., Tribolo, C., Guerin, G., Guibert, P., Lahaye, C., 2015.
+#' Combès, B., Philippe, A., Lanos, P., Mercier, N., Tribolo, C., Guérin, G., Guibert, P., Lahaye, C., 2015.
 #' A Bayesian central equivalent dose model for optically stimulated luminescence dating.
 #' Quaternary Geochronology 28, 62-70. doi:10.1016/j.quageo.2015.04.001
 #'
-#' Mercier, N., Kreutzer, S., Christophe, C., Guerin, G., Guibert, P., Lahaye, C., Lanos, P., Philippe, A.,
+#' Mercier, N., Kreutzer, S., Christophe, C., Guérin, G., Guibert, P., Lahaye, C., Lanos, P., Philippe, A.,
 #' Tribolo, C., 2016. Bayesian statistics in luminescence dating: The 'baSAR'-model and its implementation
 #' in the R package 'Luminescence'. Ancient TL 34, 14-21.
 #'
@@ -489,22 +494,19 @@ analyse_baSAR <- function(
       ## check whether this makes sense at all, just a quick and dirty test
       stopifnot(lower_centralD >= 0)
 
-      if (fit.method == "EXP") {ExpoGC <- 1 ; LinGC <-  0 }
-      if (fit.method == "LIN") {ExpoGC <- 0 ; LinGC <-  1 }
-      if (fit.method == "EXP+LIN") {ExpoGC <- 1 ; LinGC <-  1 }
-      if (fit.force_through_origin == TRUE) {GC_Origin <- 1} else {GC_Origin <- 0}
+      ExpoGC <- as.numeric(grepl("EXP", fit.method))
+      LinGC <- as.numeric(grepl("LIN", fit.method))
+      GC_Origin <- as.numeric(fit.force_through_origin)
 
       ##Include or exclude repeated dose points
       if (!fit.includingRepeatedRegPoints) {
         for (i in 1:Nb_aliquots) {
-          temp.logic <- !duplicated(data.Dose[,i], incomparables=c(0))  # logical excluding 0
+          temp.logic <- !duplicated(data.Dose[, i], incomparables = 0) # logical excluding 0
           m <- length(which(!temp.logic))
 
           data.Dose[,i] <-  c(data.Dose[,i][temp.logic], rep(NA, m))
           data.Lum[,i] <-  c(data.Lum[,i][temp.logic], rep(NA, m))
           data.sLum[,i]  <-  c(data.sLum[,i][temp.logic], rep(NA, m))
-
-          rm(m, temp.logic)
         }
       }
 
@@ -628,18 +630,17 @@ analyse_baSAR <- function(
       }
 
       ### Bayesian inputs
-      data_Liste  <- list(
-        'Dose' = data.Dose,
-        'Lum' = data.Lum,
-        'sLum' = data.sLum,
-        'LinGC' = LinGC,
-        'ExpoGC' = ExpoGC,
-        'GC_Origin' = GC_Origin,
-        'Limited_cycles' = Limited_cycles,
-        'lower_centralD' = lower_centralD,
-        'upper_centralD' = upper_centralD,
-        'Nb_aliquots' = Nb_aliquots
-      )
+      data_list  <- list(
+        Dose = data.Dose,
+        Lum = data.Lum,
+        sLum = data.sLum,
+        LinGC = LinGC,
+        ExpoGC = ExpoGC,
+        GC_Origin = GC_Origin,
+        Limited_cycles = Limited_cycles,
+        lower_centralD = lower_centralD,
+        upper_centralD = upper_centralD,
+        Nb_aliquots = Nb_aliquots)
 
       if(verbose){
         cat("\n[analyse_baSAR()] ---- baSAR-model ---- \n")
@@ -662,7 +663,7 @@ analyse_baSAR <- function(
       ##set model
       jagsfit <- rjags::jags.model(
           file = textConnection(baSAR_models[[distribution]]),
-          data = data_Liste,
+          data = data_list,
           inits = inits,
           n.chains = n.chains,
           n.adapt = Nb_Iterations,
@@ -698,14 +699,10 @@ analyse_baSAR <- function(
       output.mean <-
         round(summary(sampling_reduced)[[1]][c("central_D", "sigma_D"), 1:2], digits)
 
-        ##calculate geometric mean for the case that the distribution is log-normal
-        if(distribution == "log_normal"){
-          temp.vector <- unlist(lapply(sampling_reduced, function(x){as.vector(x[,1])}))
-          gm <- round(exp(sum(log(temp.vector))/length(temp.vector)),digits)
-          rm(temp.vector)
-        }else{
-          gm <- NULL
-        }
+      ## calculate the geometric mean if the distribution is log-normal
+      ## (in other cases gm is NULL)
+      gm <- if (distribution == "log_normal")
+              round(exp(mean(log(as.matrix(sampling_reduced)[, 1]))), digits)
 
       ##quantiles
       ##68% + 95%
@@ -811,10 +808,13 @@ analyse_baSAR <- function(
 
   # Set input -----------------------------------------------------------------------------------
 
+  par.default <- .par_defaults()
+  on.exit(par(par.default), add = TRUE)
+
   ##if the input is already of type RLum.Results, use the input and do not run
   ##all pre-calculations again
   if (inherits(object, "RLum.Results")) {
-    if(object@originator == "analyse_baSAR"){
+    .validate_originator(object, "analyse_baSAR")
 
       ##We want to use previous function arguments and recycle them
 
@@ -938,13 +938,6 @@ analyse_baSAR <- function(
      LxTx <- t(input_object[,(9 + max_cycles):(8 + 2 * max_cycles)])
      LxTx.error <-  t(input_object[,(9 + 2 * max_cycles):(8 + 3 * max_cycles)])
 
-     rm(max_cycles)
-
-    }else{
-      .throw_error("'object' is of type 'RLum.Results', ",
-                   "but was not produced by analyse_baSAR()")
-    }
-
   }else{
     if(verbose){
       cat("\n[analyse_baSAR()] ---- PRE-PROCESSING ----\n")
@@ -962,15 +955,13 @@ analyse_baSAR <- function(
     ##      .. S4
 
     ##In case an RLum.Analysis object is provided we try an ugly conversion only
-    if(inherits(object, "list") && all(vapply(object, function(x){inherits(x, "RLum.Analysis")}, logical(1)))){
-     if(verbose)
-       cat("[analyse_baSAR()] List of RLum.Analysis-objects detected ..\n")
-
-      ## set number of objects
-      n_objects <- length(object)
+    if (inherits(object, "list") &&
+        all(vapply(object, inherits, "RLum.Analysis", FUN.VALUE = logical(1)))) {
+      if (verbose)
+        cat("[analyse_baSAR()] List of RLum.Analysis-objects detected ..\n")
 
       ##stop for only one element
-      if (n_objects < 2)
+      if (length(object) < 2)
         .throw_error("At least two aliquots are needed for the calculation")
 
       ##extract wanted curves
@@ -1000,21 +991,18 @@ analyse_baSAR <- function(
       if (inherits(object, "try-error")) {
          .throw_message("Object conversion failed, NULL returned")
          return(NULL)
-       }
+      }
 
-      ##remove none-OSL curves
-      if(!all(object@METADATA[["LTYPE"]] %in% "OSL")){
+      ## remove non-OSL curves
+      rm_id <- which(object@METADATA[["LTYPE"]] != "OSL")
+      if (length(rm_id) > 0) {
         if(verbose)
           cat("\t\t  .. remove non-OSL curves\n")
-        rm_id <- which(object@METADATA[["LTYPE"]] != "OSL")
         object@METADATA <- object@METADATA[-rm_id,]
         object@DATA[rm_id] <- NULL
 
         ##reset index
-        object@METADATA[["ID"]] <- 1:length(object@METADATA[["ID"]])
-
-        ##delete objects
-        rm(rm_id)
+        object@METADATA[["ID"]] <- seq_along(object@METADATA[["ID"]])
       }
     }
 
@@ -1081,7 +1069,7 @@ analyse_baSAR <- function(
             x@METADATA <- x@METADATA[x@METADATA[["SEL"]], ]
 
             ##reset index
-            x@METADATA[["ID"]] <- 1:nrow(x@METADATA)
+            x@METADATA[["ID"]] <- seq_len(nrow(x@METADATA))
             return(x)
       })
     }
@@ -1101,7 +1089,7 @@ analyse_baSAR <- function(
     Limited_cycles <- vector()
 
     ##set information
-    for (i in 1 : length(fileBIN.list)) {
+    for (i in seq_along(fileBIN.list)) {
       Disc[[i]] <-  list()
       Grain[[i]] <-  list()
 
@@ -1154,7 +1142,7 @@ analyse_baSAR <- function(
       cat("[analyse_baSAR()] 'CSV_file' not provided, running automatic grain selection ...\n")
     }
 
-    for (k in 1:length(fileBIN.list)) {
+    for (k in seq_along(fileBIN.list)) {
       ##if the uses provides only multiple grain data (GRAIN == 0), the verification
       ##here makes not really sense and should be skipped
       if(length(unique(fileBIN.list[[k]]@METADATA[["GRAIN"]])) > 1){
@@ -1196,7 +1184,6 @@ analyse_baSAR <- function(
       ##free memory
       rm(datalu, aliquot_selection)
     }
-    rm(k)
   } else {
     ## error message used multiple times
     err.msg <- paste("'CSV_file' should have at least 3 columns for the name",
@@ -1204,14 +1191,10 @@ analyse_baSAR <- function(
 
     ##load file if we have a filename
     if (is.character(CSV_file)) {
-      ##test for valid file
-      if(!file.exists(CSV_file)){
-        .throw_error("'CSV_file' does not exist")
-      }
-
       ## import CSV file
-      datalu <- data.table::fread(CSV_file, data.table = FALSE,
-                                  skip = additional_arguments$skip)
+      datalu <- tryCatch(data.table::fread(CSV_file, data.table = FALSE,
+                                           skip = additional_arguments$skip),
+                         error = function(e) .throw_error(e$message))
 
       ###check whether data format is somehow odd, check only the first three columns
       if (ncol(datalu) < 3) {
@@ -1248,7 +1231,7 @@ analyse_baSAR <- function(
     Nb_ali <-  0
     k <- NULL
 
-    for (nn in 1:nrow(datalu)) {
+    for (nn in seq_len(nrow(datalu))) {
       if (!is.na(datalu[nn, 1]))  {
 
         ##check whether one file fits
@@ -1288,7 +1271,7 @@ analyse_baSAR <- function(
   }
 
   ###################################### loops on files_number
-  for (k in 1:length(fileBIN.list)) {
+  for (k in seq_along(fileBIN.list)) {
     Disc_Grain.list[[k]] <- list()   # data.file number
     n_aliquots_k <- length(Disc[[k]])
 
@@ -1312,15 +1295,16 @@ analyse_baSAR <- function(
     }
   }
 
+    if (length(fileBIN.list) == 0) {
+      .throw_error("All provided objects were removed")
+    }
+
   if(verbose){
     cat("\n[analyse_baSAR()] Preliminary analysis in progress ... ")
     cat("\n[analyse_baSAR()] Hang on, this may take a while ... \n")
   }
 
-  for (k in 1:length(fileBIN.list)) {
-
-    stopifnot(length(fileBIN.list[[k]]) == nrow(fileBIN.list[[k]]@METADATA))
-
+  for (k in seq_along(fileBIN.list)) {
     ## check that the data available is consistent
     length.data <- nrow(fileBIN.list[[k]]@METADATA)
     length.disc <- length(Disc[[k]])
@@ -1342,7 +1326,7 @@ analyse_baSAR <- function(
 
     ## now we override, keep in mind that we do not care about the pattern
     if(!is.null(irradiation_times))
-      irrad_time.vector <- rep(irradiation_times, length.out = length(irrad_time.vector))
+      irrad_time.vector <- rep_len(irradiation_times, length(irrad_time.vector))
 
     ##if all irradiation times are 0 we should stop here
     if (length(unique(irrad_time.vector)) == 1) {
@@ -1351,32 +1335,32 @@ analyse_baSAR <- function(
     }
 
     ### Automatic Filling - Disc_Grain.list
-    for (i in 1: length(Disc[[k]])) {
+    for (i in seq_along(Disc[[k]])) {
       disc_selected <-  as.integer(Disc[[k]][i])
       grain_selected <- if (Mono_grain) as.integer(Grain[[k]][i]) else 0
 
       ## hard break if the disc number or grain number does not fit
+      msg <- "In BIN-file '%s' %s number %d does not exist, NULL returned"
 
-         ##disc (position)
-         disc_logic <- (disc_selected == measured_discs.vector)
-         if (!any(disc_logic)) {
-           .throw_message("In BIN-file '", unique(fname), "' position number ",
-                          disc_selected, " does not exist, NULL returned")
-            return(NULL)
-          }
+      ## disc (position)
+      disc_logic <- disc_selected == measured_discs.vector
+      if (!any(disc_logic)) {
+        .throw_message(sprintf(msg, unique(fname), "position", disc_selected))
+        return(NULL)
+      }
 
-          ##grain
-          grain_logic <- (grain_selected == measured_grains.vector)
-          if (!any(grain_logic)) {
-            .throw_message("In BIN-file '", unique(fname), "' grain number ",
-                           grain_selected, " does not exist, NULL returned")
-            return(NULL)
-          }
+      ## grain
+      grain_logic <- grain_selected == measured_grains.vector
+      if (!any(grain_logic)) {
+        .throw_message(sprintf(msg, unique(fname), "grain", grain_selected))
+        return(NULL)
+      }
 
       ## if the test passed, compile index list
       index_list <- n_index.vector[disc_logic & grain_logic]
 
-      if (Mono_grain == FALSE)  {grain_selected <-1}
+      if (!Mono_grain)
+        grain_selected <- 1
 
       for (t in index_list) {
               dose.value <- irrad_time.vector[t]
@@ -1395,15 +1379,14 @@ analyse_baSAR <- function(
   ######################  Data associated with a single Disc/Grain
   max_cycles <-  0
   count <- 1
-  calc_OSLLxTxRatio_warning <- list()
 
-  for (k in 1:length(fileBIN.list)) {
+  for (k in seq_along(fileBIN.list)) {
 
     ##plot Ln and Tn curves if wanted
     ##we want to plot the Ln and Tn curves to get a better feeling
     ##The approach here is rather rough coded, but it works
     if (plot) {
-      curve_index <- vapply(1:length(Disc[[k]]), function(i) {
+      curve_index <- vapply(seq_along(Disc[[k]]), function(i) {
         dd <- as.integer(Disc[[k]][i])
         gg <- if (Mono_grain) as.integer(Grain[[k]][i]) else 1
 
@@ -1419,13 +1402,12 @@ analyse_baSAR <- function(
 
       ##open plot are
       if (!plot_singlePanels) {
-        par.default <- par()$mfrow
         par(mfrow = c(1, 2))
       }
 
       ##get natural curve and combine them in matrix
       graphics::matplot(
-        x = 1:nrow(Ln_dt),
+        x = seq_len(nrow(Ln_dt)),
         y = Ln_dt,
         col = rgb(0, 0, 0, 0.3),
         ylab = "Luminescence [a.u.]",
@@ -1440,7 +1422,7 @@ analyse_baSAR <- function(
       mtext(paste0("ALQ: ",count, ":", count + ncol(curve_index)))
 
       graphics::matplot(
-        x = 1:nrow(Tn_dt),
+        x = seq_len(nrow(Tn_dt)),
         y = Tn_dt,
         col = rgb(0, 0, 0, 0.3),
         ylab = "Luminescence [a.u.]",
@@ -1459,7 +1441,7 @@ analyse_baSAR <- function(
 
       ##reset par
       if (!plot_singlePanels) {
-        par(mfrow = par.default)
+        par(mfrow = par.default$mfrow)
       }
 
       ##remove some variables
@@ -1467,7 +1449,7 @@ analyse_baSAR <- function(
     }
 
 
-    for (i in 1:length(Disc[[k]])) {
+    for (i in seq_along(Disc[[k]])) {
       dd <- as.integer(Disc[[k]][i])
       gg <- if (Mono_grain) as.integer(Grain[[k]][i]) else 1
       sel.disc.grain <- Disc_Grain.list[[k]][[dd]][[gg]]
@@ -1485,7 +1467,7 @@ analyse_baSAR <- function(
 
         ## call calc_OSLLxTxRatio()
         ## we run this function with a warnings catcher to reduce the load of warnings for the user
-        temp_LxTx <- withCallingHandlers(
+        LxTx.table <- .warningCatcher(
           calc_OSLLxTxRatio(
             Lx.data = Lx.data,
             Tx.data = Tx.data,
@@ -1495,24 +1477,15 @@ analyse_baSAR <- function(
             background.integral.Tx = background.integral.Tx[[k]],
             background.count.distribution = additional_arguments$background.count.distribution,
             sigmab = sigmab[[k]],
-            sig0 = sig0[[k]]
-          ),
-          warning = function(c) {
-            calc_OSLLxTxRatio_warning[[i]] <<- c
-            invokeRestart("muffleWarning")
-          }
+            sig0 = sig0[[k]])$LxTx.table
         )
 
-        ##get LxTx table
-        LxTx.table <- temp_LxTx$LxTx.table
-
         Disc_Grain.list[[k]][[dd]][[gg]][[3]][nb_index] <- LxTx.table[[9]]
         Disc_Grain.list[[k]][[dd]][[gg]][[4]][nb_index] <- LxTx.table[[10]]
         Disc_Grain.list[[k]][[dd]][[gg]][[5]][nb_index] <- LxTx.table[[7]]
 
         ##free memory
         rm(LxTx.table)
-        rm(temp_LxTx)
       }
 
       ## reset `sel.disc.grain` because the data it pointed to has changed
@@ -1565,19 +1538,7 @@ analyse_baSAR <- function(
 
       count <- count + 1
     }
-
   }   ##  END of loop on BIN files
-  rm(count)
-
-  ##evaluate warnings from calc_OSLLxTxRatio()
-  if(length(calc_OSLLxTxRatio_warning)>0){
-    w_table <- table(unlist(calc_OSLLxTxRatio_warning))
-    for(w in 1:length(w_table)){
-      .throw_warning(names(w_table)[w], " This warning occurred ",
-                     w_table[w], " times")
-    }
-  }
-  rm(calc_OSLLxTxRatio_warning)
 
   Nb_aliquots <- previous.Nb_aliquots
 
@@ -1603,9 +1564,8 @@ analyse_baSAR <- function(
   )
 
   comptage <- 0
-  for (k in 1:length(fileBIN.list)) {
-
-    for (i in 1:length(Disc[[k]])) {
+  for (k in seq_along(fileBIN.list)) {
+    for (i in seq_along(Disc[[k]])) {
       dd <- as.numeric(Disc[[k]][i])
       gg <- if (Mono_grain) as.numeric(Grain[[k]][i]) else 1
 
@@ -1649,7 +1609,7 @@ analyse_baSAR <- function(
     ##clean up NaN values in the LxTx and corresponding error values
     ##the transposition of the matrix may increase the performance for very large matrices
     OUTPUT_results_reduced <- t(OUTPUT_results)
-    selection <- vapply(X = 1:ncol(OUTPUT_results_reduced), FUN = function(x){
+    selection <- vapply(seq_len(ncol(OUTPUT_results_reduced)), function(x) {
       col <- OUTPUT_results_reduced[9:(8 + 3 * max_cycles), x]
       !any(is.nan(col) | is.infinite(col))
     }, FUN.VALUE = logical(1))
@@ -1700,30 +1660,25 @@ analyse_baSAR <- function(
   ## that "We set the bounds for the prior on the central dose D, Dmin = 0 Gy and
   ## Dmax = 1000 Gy, to cover the likely range of possible values for D.
 
+  msg <- paste("You have modified the %s central_D boundary while applying",
+               "a predefined model. This is possible but not recommended")
+
     ##check if something is set in method control, if not, set it
     if (is.null(method_control[["upper_centralD"]])) {
       method_control <- c(method_control, upper_centralD = 1000)
-    }else{
-      if (distribution %in% c("normal", "cauchy", "log_normal")) {
-        .throw_warning("You have modified the upper central_D boundary ",
-                       "while applying a predefined model. This is ",
-                       "possible but not recommended!")
-      }
+    } else if (distribution %in% c("normal", "cauchy", "log_normal")) {
+      .throw_warning(sprintf(msg, "upper"))
     }
 
     ## do the same for the lower_centralD, just to have everything in one place
     if (is.null(method_control[["lower_centralD"]])) {
       method_control <- c(method_control, lower_centralD = 0)
-    }else{
-      if (distribution %in% c("normal", "cauchy", "log_normal")) {
-        .throw_warning("You have modified the lower central_D boundary ",
-                       "while applying a predefined model. This is ",
-                       "possible but not recommended!")
-      }
+    } else if (distribution %in% c("normal", "cauchy", "log_normal")) {
+      .throw_warning(sprintf(msg, "lower"))
     }
 
-    if(min(input_object[["DE"]][input_object[["DE"]] > 0], na.rm = TRUE) < method_control$lower_centralD |
-       max(input_object[["DE"]], na.rm = TRUE) > method_control$upper_centralD){
+    if (min(input_object[["DE"]][input_object[["DE"]] > 0], na.rm = TRUE) < method_control$lower_centralD ||
+        max(input_object[["DE"]], na.rm = TRUE) > method_control$upper_centralD) {
       .throw_warning("Your lower_centralD and/or upper_centralD values ",
                      "seem not to fit to your input data. This may indicate ",
                      "a wronlgy set 'source_doserate'.")
@@ -1758,7 +1713,6 @@ analyse_baSAR <- function(
       ##if it comes from the previous call, it is, unfortunately not that simple
       if(!is.null(function_arguments$source_doserate)){
         source_doserate <- eval(function_arguments$source_doserate)
-
         if (!inherits(source_doserate, "list")) {
           source_doserate <- list(source_doserate)
         }
@@ -1842,7 +1796,7 @@ analyse_baSAR <- function(
   if(plot){
 
     ## deprecated argument
-    if ("plot.single" %in% names(list(...))) {
+    if ("plot.single" %in% ...names()) {
       plot_singlePanels <- list(...)$plot.single
       .throw_warning("'plot.single' is deprecated, use 'plot_singlePanels' ",
                      "instead")
@@ -1882,26 +1836,27 @@ analyse_baSAR <- function(
     ##get list with D values
     ##get list out of it
     plot_matrix <- as.matrix(results[[2]][, grep(varnames, pattern = "^D")])
-    aliquot_quantiles <- t(matrixStats::colQuantiles(plot_matrix, probs = c(0.25, 0.75),
-                                                     drop = FALSE))
+    aliquot_quantiles <- apply(plot_matrix, 2, quantile, c(0.25, 0.75))
 
     ##define boxplot colours ... we have red and orange
-    box.col <- vapply(1:ncol(aliquot_quantiles), function(x){
-      if(aliquot_quantiles[2,x] < results[[1]][,c("CENTRAL_Q_.025")] |
-         aliquot_quantiles[1,x] > results[[1]][,c("CENTRAL_Q_.975")]
-      ){
-        col[2]
-      }else if(aliquot_quantiles[2,x] < results[[1]][,c("CENTRAL_Q_.16")] |
-               aliquot_quantiles[1,x] > results[[1]][,c("CENTRAL_Q_.84")]){
-        "orange"
-      }else{
-        "white"
-      }
+    box.col <- vapply(seq_len(ncol(aliquot_quantiles)), function(x) {
+      idx <- 1
+      if (aliquot_quantiles[2, x] < results[[1]][, "CENTRAL_Q_.16"] ||
+          aliquot_quantiles[1, x] > results[[1]][, "CENTRAL_Q_.84"])
+        idx <- idx + 1
+      if (aliquot_quantiles[2, x] < results[[1]][, "CENTRAL_Q_.025"] ||
+          aliquot_quantiles[1, x] > results[[1]][, "CENTRAL_Q_.975"])
+        idx <- idx + 1
+      c("white", "orange", col[2])[idx]
     }, FUN.VALUE = character(1))
 
+    ## make selection according to the model for the curve plotting
+    ExpoGC <- as.numeric(grepl("EXP", fit.method))
+    LinGC <- as.numeric(grepl("LIN", fit.method))
+    GC_Origin <- as.numeric(fit.force_through_origin)
+
     ## to assure a minimum of quality not more then 15 boxes are plotted in each plot
     i <- 1
-
     while(i < ncol(plot_matrix)){
       step <- min(ncol(plot_matrix), i + 14)
       plot_check <- try(graphics::boxplot(
@@ -1922,7 +1877,6 @@ analyse_baSAR <- function(
         axis(side = 2, at = 1:15, labels = as.character(c(i:step, rep(" ", length = 15 - length(i:step)))),
              cex.axis = 0.8
         )
-
       }else{
         axis(side = 2, at = 1:15, labels = as.character(i:step), cex.axis = 0.8)
       }
@@ -1931,15 +1885,15 @@ analyse_baSAR <- function(
       ##HPD - 68%
       lines(
         x = c(
-          results[[1]][, c("CENTRAL_Q_.16")], results[[1]][, c("CENTRAL_Q_.16")],
-          results[[1]][, c("CENTRAL_Q_.84")], results[[1]][, c("CENTRAL_Q_.84")]),
+          results[[1]][, "CENTRAL_Q_.16"], results[[1]][, "CENTRAL_Q_.16"],
+          results[[1]][, "CENTRAL_Q_.84"], results[[1]][, "CENTRAL_Q_.84"]),
         y = c(par()$usr[3], 16, 16, par()$usr[3]),
         lty = 3,
         col = col[3],
         lwd = 1.5
       )
       text(
-        x = results[[1]][, c("CENTRAL")],
+        x = results[[1]][, "CENTRAL"],
         y = 16,
         labels = "68 %",
         pos = 3,
@@ -1950,8 +1904,8 @@ analyse_baSAR <- function(
       ##HPD - 98 %%
       lines(
         x = c(
-          results[[1]][, c("CENTRAL_Q_.025")], results[[1]][, c("CENTRAL_Q_.025")],
-          results[[1]][, c("CENTRAL_Q_.975")], results[[1]][, c("CENTRAL_Q_.975")]),
+          results[[1]][, "CENTRAL_Q_.025"], results[[1]][, "CENTRAL_Q_.025"],
+          results[[1]][, "CENTRAL_Q_.975"], results[[1]][, "CENTRAL_Q_.975"]),
         y = c(par()$usr[3], 17.5, 17.5, par()$usr[3]),
         lty = 3,
         col = col[2],
@@ -1959,7 +1913,7 @@ analyse_baSAR <- function(
       )
 
       text(
-        x = results[[1]][, c("CENTRAL")],
+        x = results[[1]][, "CENTRAL"],
         y = 17.5,
         labels = "95 %",
         pos = 3,
@@ -1969,11 +1923,9 @@ analyse_baSAR <- function(
       ##update counter
       i <- i + 15
     }
-    rm(plot_matrix)
 
     if (!plot_singlePanels) {
       par(mfrow = c(1,2))
-      on.exit(par(mfrow = c(1,1), bg = "white", xpd = FALSE), add = TRUE)
     }
     ##////////////////////////////////////////////////////////////////////////////////////////////
     ##DOSE RESPONSE CURVES AND Lx/Tx VALUES
@@ -1996,12 +1948,6 @@ analyse_baSAR <- function(
       ##free memory
       rm(list_selection)
 
-      ##make selection according to the model for the curve plotting
-      if (fit.method == "EXP") {ExpoGC <- 1 ; LinGC <-  0 }
-      if (fit.method == "LIN") {ExpoGC <- 0 ; LinGC <-  1 }
-      if (fit.method == "EXP+LIN") {ExpoGC <- 1 ; LinGC <-  1 }
-      if (fit.force_through_origin) {GC_Origin <- 0} else {GC_Origin <- 1}
-
       ##add choise for own provided model
       fit.method_plot <- fit.method
       if(!is.null(baSAR_model)){
@@ -2039,14 +1985,14 @@ analyse_baSAR <- function(
           if (nrow(plot_matrix) != 0 && all(var.required %in% variable.names)) {
             ##plot individual dose response curves
             x <- NA
-            for (i in seq(1, nrow(plot_matrix), length.out = 1000)) {
+            for (i in seq_len(min(nrow(plot_matrix), 1000))) {
               curve(
                   GC_Origin * plot_matrix[i, "g"] +
                   LinGC * (plot_matrix[i, "c"] * x) +
                   ExpoGC * (plot_matrix[i, "a"] *
-                            (1 - exp (-x / plot_matrix[i, "b"]))),
+                            (1 - exp(-x / plot_matrix[i, "b"]))),
                   add = TRUE,
-                  col = rgb(0, 0, 0, .1)
+                  col = rgb(0, 0, 0, 0.1)
               )
             }
           }else{
@@ -2190,7 +2136,7 @@ analyse_baSAR <- function(
   }
 
   # Return --------------------------------------------------------------------------------------
-  return(set_RLum(
+  set_RLum(
     class = "RLum.Results",
     data = list(
       summary = results[[1]],
@@ -2200,5 +2146,5 @@ analyse_baSAR <- function(
       removed_aliquots = removed_aliquots
       ),
     info = list(call = sys.call())
-  ))
+  )
 }
