@@ -153,7 +153,7 @@ calc_AliquotSize <- function(
   sample.diameter,
   packing.density = 0.65,
   MC = TRUE,
-  grains.counted,
+  grains.counted = NULL,
   sample_carrier.diameter = 9.8,
   plot = TRUE,
   ...
@@ -163,11 +163,14 @@ calc_AliquotSize <- function(
 
   ## Integrity checks -------------------------------------------------------
 
-  if (missing(grain.size) ||
-      length(grain.size) == 0 || length(grain.size) > 2) {
+  .validate_class(grain.size, c("numeric", "integer"))
+  if (length(grain.size) == 0 || length(grain.size) > 2) {
     .throw_error("Please provide the mean grain size or the range ",
                  "of grain sizes (in microns)")
   }
+  if (anyNA(grain.size) || any(grain.size <= 0)) {
+    .throw_error("'grain.size' should contain positive values")
+  }
 
   .validate_positive_scalar(packing.density)
   if (is.infinite(packing.density)) {
@@ -185,18 +188,19 @@ calc_AliquotSize <- function(
                    "specified for a sample carrier of ", sample_carrier.diameter,
                    " mm, values will be capped to the sample carrier size")
 
-  if (!missing(grains.counted) && MC == TRUE) {
-    MC = FALSE
-    message("\nMonte Carlo simulation is only available for estimating the ",
-            "amount of grains on the sample disc, 'MC' reset to FALSE\n")
+  .validate_logical_scalar(MC)
+  if (!is.null(grains.counted) && MC) {
+    MC <- FALSE
+    .throw_message("Monte Carlo simulation is only available for estimating the ",
+                   "amount of grains on the sample disc, 'MC' reset to FALSE",
+                   error = FALSE)
   }
 
-  if(MC == TRUE && length(grain.size) != 2) {
+  if (MC && length(grain.size) != 2) {
     .throw_error("'grain.size' must be a vector containing the min and max ",
                  "grain size when using Monte Carlo simulations")
   }
 
-
   ##==========================================================================##
   ## ... ARGUMENTS
   ##==========================================================================##
@@ -207,6 +211,10 @@ calc_AliquotSize <- function(
 
   # override settings with user arguments
   settings <- modifyList(settings, list(...))
+  if (MC) {
+    .validate_positive_scalar(settings$MC.iter, int = TRUE, null.ok = TRUE,
+                              name = "'MC.iter'")
+  }
 
   MC.n <- MC.stats <- MC.n.kde <- MC.t.test <- MC.q <- NULL
 
@@ -217,7 +225,7 @@ calc_AliquotSize <- function(
   # calculate the mean grain size
   range.flag<- FALSE
   if(length(grain.size) == 2) {
-    gs.range<- grain.size
+    gs.range <- sort(grain.size)
     grain.size<- mean(grain.size)
     range.flag<- TRUE
   }
@@ -229,13 +237,13 @@ calc_AliquotSize <- function(
   }
 
   # calculate the amount of grains on the aliquot
-  if(missing(grains.counted) == TRUE) {
+  if (is.null(grains.counted)) {
     n.grains<- calc_n(sample.diameter, grain.size, packing.density)
 
     ##========================================================================##
     ## MONTE CARLO SIMULATION
 
-    if(MC == TRUE && range.flag == TRUE) {
+    if (MC && range.flag) {
 
       # create a random set of packing densities assuming a normal
       # distribution with the empirically determined standard deviation of
@@ -262,7 +270,7 @@ calc_AliquotSize <- function(
       # create random samples assuming a normal distribution
       # with the mean grain size as mean and half the range (min:max)
       # as standard deviation. For a more conservative estimate this
-      # is further devided by 2, so half the range is regarded as
+      # is further divided by 2, so half the range is regarded as
       # two sigma.
       gs.mc<- rnorm(settings$MC.iter, grain.size, diff(gs.range)/4)
 
@@ -270,13 +278,18 @@ calc_AliquotSize <- function(
       # the mean for each sample. This gives an approximation of the variation
       # in mean grain size on the sample disc
       gs.mc.sampleMean <-
-        sapply(1:length(gs.mc),
-               function(x) mean(sample(gs.mc,
-                                       calc_n(
-                                           sample(sd.mc, size = 1),
-                                           grain.size,
-                                           sample(d.mc, size = 1)
-                                       ), replace = TRUE)))
+        if (diff(gs.range) > 0) {
+          sapply(1:length(gs.mc),
+                 function(x) mean(sample(gs.mc,
+                                         calc_n(
+                                             sample(sd.mc, size = 1),
+                                             grain.size,
+                                             sample(d.mc, size = 1)
+                                         ),
+                                         replace = TRUE)))
+        } else {
+          grain.size
+        }
 
       # calculate n for each MC data set
       MC.n <- apply(data.frame(sd.mc, gs.mc.sampleMean, d.mc), 1,
@@ -301,7 +314,7 @@ calc_AliquotSize <- function(
   ##========================================================================##
   ## CALCULATE PACKING DENSITY
 
-  if (!missing(grains.counted)) {
+  if (!is.null(grains.counted)) {
     area.container <- pi * (sample.diameter / 2)^2
     area.grains <- pi * (grain.size / 1000 / 2)^2 * grains.counted
     packing.density <- area.grains / area.container
@@ -317,29 +330,22 @@ calc_AliquotSize <- function(
     cat("\n\n ---------------------------------------------------------")
     cat("\n mean grain size (microns)  :", grain.size)
     cat("\n sample diameter (mm)       :", sample.diameter)
-    if(missing(grains.counted) == FALSE) {
+    if (!is.null(grains.counted)) {
       if(length(grains.counted) == 1) {
         cat("\n counted grains             :", grains.counted)
-      } else {
-        cat("\n mean counted grains        :", round(mean(grains.counted)))
-      }
-    }
-    if(missing(grains.counted) == TRUE) {
-      cat("\n packing density            :", round(packing.density, 3))
-    }
-    if(missing(grains.counted) == FALSE) {
-      if(length(grains.counted) == 1) {
         cat("\n packing density            :", round(packing.density, 3))
       } else {
+        cat("\n mean counted grains        :", round(mean(grains.counted)))
         cat("\n mean packing density       :", round(mean(packing.density), 3))
         cat("\n standard deviation         :", round(std.d, 3))
       }
     }
-    if(missing(grains.counted) == TRUE) {
+    if (is.null(grains.counted)) {
+      cat("\n packing density            :", round(packing.density, 3))
       cat("\n number of grains           :", round(n.grains, 0))
     }
 
-    if(MC == TRUE && range.flag == TRUE) {
+    if (MC && range.flag) {
       cat("\n\n --------------- Monte Carlo Estimates -------------------")
       cat("\n number of iterations (n)     :", settings$MC.iter)
       cat("\n median                       :", round(MC.stats$median))
@@ -356,7 +362,7 @@ calc_AliquotSize <- function(
   ##RETURN VALUES
   ##==========================================================================##
 
-  if (missing(grains.counted))
+  if (is.null(grains.counted))
     grains.counted <- NA
   else
     n.grains <- NA
@@ -403,22 +409,13 @@ calc_AliquotSize <- function(
     )
     settings <- modifyList(settings, list(...))
 
-    ## extract relevant data
-    MC.n <- object@data$MC$estimates
-    MC.n.kde <- object@data$MC$kde
-    MC.stats <- object@data$MC$statistics
-    MC.q <- object@data$MC$quantile
-    MC.iter <- object@data$args$MC.iter
+    par.default <- .par_defaults()
+    on.exit(par(par.default), add = TRUE)
 
     ## set layout of plotting device
     nrow.splits <- if (settings$boxplot) 2 else 1
     graphics::layout(matrix(c(1, 1, nrow.splits)), nrow.splits, 1)
-    par(cex = settings$cex)
-
-    ## plot MC estimate distribution
-
-    ## set margins (bottom, left, top, right)
-    par(mar = c(if (settings$boxplot) 2 else 5, 5, 5, 3))
+    par(cex = settings$cex, mar = c(if (settings$boxplot) 2 else 5, 5, 5, 3))
 
     ## plot histogram
     hist(MC.n, freq = FALSE, col = settings$col,
@@ -440,7 +437,7 @@ calc_AliquotSize <- function(
 
     ## add title and subtitle
     if (settings$summary) {
-      mtext(as.expression(bquote(italic(n) == .(MC.iter) ~ "|" ~
+      mtext(as.expression(bquote(italic(n) == .(settings$MC.iter) ~ "|" ~
                                  italic(hat(mu)) == .(round(MC.stats$mean)) ~ "|" ~
                                  italic(hat(sigma)) == .(round(MC.stats$sd.abs)) ~ "|" ~
                                  italic(frac(hat(sigma), sqrt(n))) == .(round(MC.stats$se.abs)) ~ "|" ~
@@ -462,7 +459,7 @@ calc_AliquotSize <- function(
       plot(NA, type = "n", xlim = c(min(MC.n) * 0.95, max(MC.n) * 1.05),
            xlab = settings$xlab, ylim = c(0.5, 1.5),
            xaxt = "n", yaxt = "n", ylab = "")
-      graphics::boxplot(MC.n, horizontal = TRUE, add = TRUE, bty = "n")
+      graphics::boxplot(MC.n, horizontal = TRUE, add = TRUE, bty = "n", cex = 1)
     }
   }
 
