@@ -3,7 +3,7 @@
 #' @description
 #' This functions calculates the Average Dose and its extrinsic dispersion,
 #' estimating the standard errors by bootstrapping based on the Average
-#' Dose Model by Guerin et al., 2017.
+#' Dose Model by Guérin et al., 2017.
 #'
 #' **`sigma_m`**\cr
 #'
@@ -96,7 +96,7 @@
 #' dose and the sigma values.
 #'
 #' @references
-#' Guerin, G., Christophe, C., Philippe, A., Murray, A.S., Thomsen, K.J., Tribolo, C., Urbanova, P.,
+#' Guérin, G., Christophe, C., Philippe, A., Murray, A.S., Thomsen, K.J., Tribolo, C., Urbanova, P.,
 #' Jain, M., Guibert, P., Mercier, N., Kreutzer, S., Lahaye, C., 2017. Absorbed dose, equivalent dose,
 #' measured dose rates, and implications for OSL age estimates: Introducing the Average Dose Model.
 #' Quaternary Geochronology 1-32. doi:10.1016/j.quageo.2017.04.002
@@ -360,8 +360,8 @@ calc_AverageDose <- function(
   IC <- rbind(IC_delta, IC_sigma_d)
 
   # standard errors
-  sedelta <- sqrt ((1/(Nb_BE-1))*sum((dstar[,1]-mean(dstar[,1]))^2))
-  sesigma_d <- sqrt ((1/(Nb_BE-1))*sum((dstar[,2]-mean(dstar[,2]))^2))
+  sedelta <- sqrt((1 / (Nb_BE - 1)) * sum((dstar[, 1] - mean(dstar[, 1]))^2))
+  sesigma_d <- sqrt((1 / (Nb_BE - 1)) * sum((dstar[, 2] - mean(dstar[, 2]))^2))
 
   ##Terminal output
   if (verbose) {
@@ -439,17 +439,15 @@ calc_AverageDose <- function(
 
   ##expand all elements in the list
   ##problem: the user might provid only one item, then the code will break
-  plot_settings.user <- lapply(list(...), function(x){
-    rep(x, length = 3)
-  })
+  plot_settings.user <- lapply(list(...), rep, length = 3)
 
   ##modify
   plot_settings <- modifyList(plot_settings, plot_settings.user)
 
   ##get change par setting and reset on exit
   if(plot) {
-    par.default <- par()$mfrow
-    on.exit(par(mfrow = par.default), add = TRUE)
+    par.default <- .par_defaults()
+    on.exit(par(par.default), add = TRUE)
     par(mfrow = c(1,3))
   }
 
