@@ -21,9 +21,8 @@
 #' for [data.frame]: two columns with De `(data[,1])` and De error `(data[,2])`
 #'
 #' @param sigmab [numeric] (*with default*):
-#' additional spread in De values.
-#' This value represents the expected overdispersion in the data should the sample be
-#' well-bleached (Cunningham & Walling 2012, p. 100).
+#' additional spread in De values, representing the expected overdispersion in
+#' the data should the sample be well-bleached (Cunningham & Wallinga 2012, p. 100).
 #' **NOTE**: For the logged model (`log = TRUE`) this value must be
 #' a fraction, e.g. 0.2 (= 20%). If the un-logged model is used (`log = FALSE`),
 #' `sigmab` must be provided in the same absolute units of the De values
@@ -115,10 +114,8 @@ calc_CommonDose <- function(
   if (ncol(data) < 2) {
     .throw_error("'data' object must have two columns")
   }
-  if(!missing(sigmab)) {
-    if (sigmab < 0 || sigmab > 1) {
+  if (!missing(sigmab) && (sigmab < 0 || sigmab > 1)) {
       .throw_error("'sigmab' must be a value between 0 and 1")
-    }
   }
   .validate_logical_scalar(log)
 
@@ -190,12 +187,10 @@ calc_CommonDose <- function(
   call<- sys.call()
   args<- list(log=log, sigmab=sigmab)
 
-  newRLumResults.calc_CommonDose<- set_RLum(
+  set_RLum(
     class = "RLum.Results",
     data = list(summary = summary,
                 data = data,
                 args = args,
                 call = call))
-
-  invisible(newRLumResults.calc_CommonDose)
 }
