@@ -201,7 +201,7 @@
 #' colour of the additional lines.
 #'
 #' @param line.lty [integer]:
-#' line type of additional lines
+#' line type of additional lines.
 #'
 #' @param line.label [character]:
 #' labels for the additional lines.
@@ -233,7 +233,7 @@
 #' @return
 #' Returns a plot object and, optionally, a list with plot calculus data.
 #'
-#' @section Function version: 0.1.18
+#' @section Function version: 0.1.20
 #'
 #' @author
 #' Michael Dietze, GFZ Potsdam (Germany)\cr
@@ -266,8 +266,7 @@
 #'                  log.z = FALSE)
 #'
 #' ## now with output of the plot parameters
-#' plot1 <- plot_AbanicoPlot(data = ExampleData.DeValues,
-#'                           output = TRUE)
+#' plot1 <- plot_AbanicoPlot(data = ExampleData.DeValues)
 #' str(plot1)
 #' plot1$zlim
 #'
@@ -414,8 +413,7 @@
 #' ## now with manually added plot content
 #' ## create empty plot with numeric output
 #' AP <- plot_AbanicoPlot(data = ExampleData.DeValues,
-#'                        pch = NA,
-#'                        output = TRUE)
+#'                        pch = NA)
 #'
 #' ## identify data in 2 sigma range
 #' in_2sigma <- AP$data[[1]]$data.in.2s
@@ -446,9 +444,9 @@ plot_AbanicoPlot <- function(
   summary = c("n", "in.2s"),
   summary.pos = "sub",
   summary.method = "MCM",
-  legend,
-  legend.pos,
-  stats,
+  legend = NULL,
+  legend.pos = "topleft",
+  stats = NULL,
   rug = FALSE,
   kde = TRUE,
   hist = FALSE,
@@ -456,14 +454,14 @@ plot_AbanicoPlot <- function(
   boxplot = FALSE,
   y.axis = TRUE,
   error.bars = FALSE,
-  bar,
-  bar.col,
-  polygon.col,
-  line,
-  line.col,
-  line.lty,
-  line.label,
-  grid.col,
+  bar = NULL,
+  bar.col = NULL,
+  polygon.col = NULL,
+  line = NULL,
+  line.col = NULL,
+  line.lty = NULL,
+  line.label = NULL,
+  grid.col = NULL,
   frame = 1,
   bw = "SJ",
   interactive = FALSE,
@@ -487,20 +485,20 @@ plot_AbanicoPlot <- function(
       data[[i]] <- get_RLum(data[[i]], "data")
 
       if (ncol(data[[i]]) < 2) {
-        .throw_error("Data set (", i, ") has fewer than 2 columns: data ",
+        .throw_error("Data set ", i, " has fewer than 2 columns: data ",
                      "without errors cannot be displayed")
       }
 
-      data[[i]] <- data[[i]][,c(1:2)]
+      data[[i]] <- data[[i]][, 1:2]
   }
 
   ## optionally, remove NA-values
-  if(na.rm == TRUE) {
+  if (na.rm) {
     for(i in seq_along(data)) {
       n.NA <- sum(!stats::complete.cases(data[[i]]))
       if (n.NA > 0) {
-        .throw_message("Data set (", i, "): ", n.NA, " NA value",
-                       ifelse (n.NA > 1, "s", ""), " excluded", error = FALSE)
+        .throw_message("Data set ", i, ": ", n.NA, " NA value",
+                       ifelse(n.NA > 1, "s", ""), " excluded", error = FALSE)
         data[[i]] <- na.exclude(data[[i]])
       }
     }
@@ -515,15 +513,12 @@ plot_AbanicoPlot <- function(
   }
   ##(2)
   ##check for sets with only 1 row or 0 rows at all
-  else if(any(sapply(data, nrow) <= 1)){
+  else if (any(sapply(data, nrow) < 2)) {
     ##select problematic sets and remove the entries from the list
     NArm.id <- which(sapply(data, nrow) <= 1)
     data[NArm.id] <- NULL
-
-    .throw_warning("Data sets ", paste(NArm.id, collapse = ", "),
-                   " are found to be empty or consisting of only 1 row. Sets removed!")
-
-    rm(NArm.id)
+    .throw_warning("Data set ", toString(NArm.id),
+                   " empty or consisting of only 1 row, removed")
 
     ##unfortunately, the data set might become now empty at all
     if(length(data) == 0){
@@ -534,22 +529,22 @@ plot_AbanicoPlot <- function(
 
   ## check for zero-error values
   for(i in 1:length(data)) {
-    if(sum(data[[i]][,2] == 0) > 0) {
+    if (any(data[[i]][, 2] == 0)) {
       data[[i]] <- data[[i]][data[[i]][,2] > 0,]
-
-      if(nrow(data[[i]]) < 1) {
+      if (nrow(data[[i]]) < 1){
         .throw_error("Data set contains only values with zero errors")
       }
-
       .throw_warning("Values with zero errors cannot be displayed and were removed")
     }
   }
 
   ## check for 0 values in dataset for log
-  if (log.z[1]) {
+  .validate_logical_scalar(log.z)
+  if (log.z) {
     for(i in 1:length(data)) {
       if(any(data[[i]][[1]] == 0)) {
-        .throw_warning("Found zero values in x-column of dataset ", i, ": set log.z = FALSE")
+        .throw_warning("Found zero values in x-column of dataset ", i,
+                       ", 'log.z' set to FALSE")
         log.z <- FALSE
       }
     }
@@ -559,6 +554,11 @@ plot_AbanicoPlot <- function(
   .validate_positive_scalar(plot.ratio)
   .validate_logical_scalar(rotate)
   .validate_logical_scalar(rug)
+  .validate_logical_scalar(kde)
+  .validate_logical_scalar(hist)
+  .validate_logical_scalar(dots)
+  .validate_logical_scalar(boxplot)
+  .validate_logical_scalar(error.bars)
 
   if (!is.numeric(z.0)) {
     .validate_class(z.0, "character")
@@ -572,56 +572,49 @@ plot_AbanicoPlot <- function(
   if (!dispersion %in% main.choices && !grepl("^p[0-9][0-9]$", dispersion))
     dispersion <- .validate_args(dispersion, main.choices, extra = extra.choice)
 
+  valid.pos <- c("left", "center", "right", "topleft", "top", "topright",
+                 "bottomleft", "bottom", "bottomright")
   .validate_class(summary, "character")
-  .validate_class(summary.pos, c("numeric", "character"))
   if (is.numeric(summary.pos)) {
     .validate_length(summary.pos, 2)
   }
   else {
-    .validate_args(summary.pos, c("sub", "left", "center", "right",
-                                  "topleft", "top", "topright",
-                                  "bottomleft", "bottom", "bottomright"))
+    summary.pos <- .validate_args(summary.pos, c("sub", valid.pos))
+  }
+  .validate_class(legend, "character", null.ok = TRUE)
+  if (is.numeric(legend.pos)) {
+    .validate_length(legend.pos, 2)
+  } else {
+    legend.pos <- .validate_args(legend.pos, valid.pos)
   }
 
-  ## save original plot parameters and restore them upon end or stop
-  par.default <- par(no.readonly = TRUE)
-  cex_old <- par()$cex
-
-  ## this ensures par() is respected for several plots on one page
-  if(sum(par()$mfrow) == 2 & sum(par()$mfcol) == 2){
-    on.exit(par(par.default), add = TRUE)
-  }
+  frame <- .validate_args(frame, c(0, 1, 2, 3))
 
   ## check/set layout definitions
   layout <- get_Layout(layout = list(...)$layout %||% "default")
 
-  if(missing(stats))
-    stats <- numeric(0)
-
-  if(missing(bar))
+  if (is.null(bar))
     bar <- rep(TRUE, length(data))
 
-  if(missing(bar.col)) {
-    bar.fill <- rep(x = rep(x = layout$abanico$colour$bar.fill,
-                            length.out = length(data)), length(bar))
-    bar.line <- rep(rep(layout$abanico$colour$bar.line,
-                        length.out = length(data)), length(bar))
+  if (is.null(bar.col)) {
+    bar.fill <- rep(rep_len(layout$abanico$colour$bar.fill, length(data)),
+                    length(bar))
+    bar.line <- rep(rep_len(layout$abanico$colour$bar.line, length(data)),
+                    length(bar))
   } else {
     bar.fill <- bar.col
     bar.line <- NA
   }
 
-  if(missing(polygon.col)) {
-    polygon.fill <- rep(layout$abanico$colour$poly.fill,
-                        length.out = length(data))
-    polygon.line <- rep(layout$abanico$colour$poly.line,
-                        length.out = length(data))
+  if (is.null(polygon.col)) {
+    polygon.fill <- rep_len(layout$abanico$colour$poly.fill, length(data))
+    polygon.line <- rep_len(layout$abanico$colour$poly.line, length(data))
   } else {
     polygon.fill <- polygon.col
     polygon.line <- NA
   }
 
-  if(missing(grid.col)) {
+  if (is.null(grid.col)) {
     grid.major <- layout$abanico$colour$grid.major
     grid.minor <- layout$abanico$colour$grid.minor
   } else {
@@ -632,20 +625,8 @@ plot_AbanicoPlot <- function(
   ## create preliminary global data set
   De.global <- unlist(lapply(data, function(x) x[, 1]))
 
-  ## calculate major preliminary tick values and tick difference
+  ## additional arguments
   extraArgs <- list(...)
-  if ("zlim" %in% names(extraArgs) && !is.null(extraArgs$zlim)) {
-    limits.z <- extraArgs$zlim
-    .validate_class(limits.z, "numeric", name = "'zlim'")
-  } else {
-    z.span <- (mean(De.global) * 0.5) / (sd(De.global) * 100)
-    z.span <- ifelse(z.span > 1, 0.9, z.span)
-    limits.z <- c((ifelse(min(De.global) <= 0, 1.1, 0.9) - z.span) *
-                    min(De.global),
-                  (1.1 + z.span) * max(De.global))
-  }
-
-  ticks <- extraArgs$at %||% round(pretty(limits.z, n = 5), 3)
   breaks <- extraArgs$breaks %||% "Sturges"
   fun <- isTRUE(list(...)$fun)
 
@@ -677,7 +658,7 @@ plot_AbanicoPlot <- function(
   }
 
   ## optionally add correction dose to data set and adjust error
-  if(log.z[1]) {
+  if (log.z) {
     for(i in 1:length(data))
       data[[i]][,1] <- data[[i]][,1] + De.add
 
@@ -710,7 +691,7 @@ plot_AbanicoPlot <- function(
   } else {
     ## z.0 is numeric
     z.central <- lapply(1:length(data), function(x){
-      rep(ifelse(log.z == TRUE,
+      rep(ifelse(log.z,
                  log(z.0),
                  z.0),
           length(data[[x]][,3]))})
@@ -729,7 +710,7 @@ plot_AbanicoPlot <- function(
   })
 
   ## append optional weights for KDE curve
-  use.weights <- "weights" %in% names(extraArgs) && extraArgs$weights == TRUE
+  use.weights <- "weights" %in% names(extraArgs) && extraArgs$weights
   data <- lapply(data, function(x) {
     cbind(x,
           weights = if (use.weights) (1 / x[, 2]) / sum(1 / x[, 2]^2)
@@ -769,8 +750,8 @@ plot_AbanicoPlot <- function(
     z.central.global <- stats.global$unweighted[[z.0]]
   } else  if(z.0 == "mean.weighted") {
     z.central.global <- stats.global$weighted$mean
-  } else if(is.numeric(z.0) == TRUE) {
-    z.central.global <- ifelse(log.z == TRUE,
+  } else if(is.numeric(z.0)) {
+    z.central.global <- ifelse(log.z,
                                log(z.0),
                                z.0)
   }
@@ -803,7 +784,6 @@ plot_AbanicoPlot <- function(
 
   ## print message for too small scatter
   if(max(abs(1 / data.global[6])) < 0.02) {
-    small.sigma <- TRUE
     .throw_message("Small standardised estimate scatter, toggle off y.axis?",
                    error = FALSE)
   }
@@ -814,29 +794,24 @@ plot_AbanicoPlot <- function(
   main <- extraArgs$main %||% expression(D[e] * " " * "distribution")
   sub <- extraArgs$sub %||% ""
 
-  if("xlab" %in% names(extraArgs)) {
-    if(length(extraArgs$xlab) != 2) {
-      if (length(extraArgs$xlab) == 3) {
-        xlab <- c(extraArgs$xlab[1:2], "Density")
-      } else {
-        .throw_error("'xlab' must have length 2")
-      }
-    } else {xlab <- c(extraArgs$xlab, "Density")}
-  } else {
-    xlab <- c(if(log.z == TRUE) {
-      "Relative standard error [%]"
-    } else {
-      "Standard error"
-    },
-    "Precision",
-    "Density")
-  }
-
-  ylab <-extraArgs$ylab %||% "Standardised estimate"
+  xlab <- if ("xlab" %in% names(extraArgs)) {
+            if (!length(extraArgs$xlab) %in% c(2, 3))
+              .throw_error("'xlab' must have length 2")
+            c(extraArgs$xlab[1:2], "Density")
+          } else {
+            c(if (log.z) "Relative standard error [%]" else "Standard error",
+              "Precision",
+              "Density")
+          }
+  ylab <- extraArgs$ylab %||% "Standardised estimate"
   zlab <- extraArgs$zlab %||% expression(D[e] * " " * "[Gy]")
 
   if ("zlim" %in% names(extraArgs) && !is.null(extraArgs$zlim)) {
     limits.z <- extraArgs$zlim
+    .validate_class(limits.z, "numeric", name = "'zlim'")
+    if (log.z && any(limits.z <= 0)) {
+      .throw_error("'zlim' should only contain positive values when 'log.z = TRUE'")
+    }
   } else {
     z.span <- (mean(data.global[,1]) * 0.5) / (sd(data.global[,1]) * 100)
     z.span <- ifelse(z.span > 1, 0.9, z.span)
@@ -847,15 +822,14 @@ plot_AbanicoPlot <- function(
   if ("xlim" %in% names(extraArgs) && !is.null(extraArgs$xlim)) {
     limits.x <- extraArgs$xlim
     .validate_class(limits.x, "numeric", name = "'xlim'")
+    if (limits.x[1] != 0) {
+      .throw_warning("Lower x-axis limit was ", limits.x[1], ", reset to zero")
+      limits.x[1] <- 0
+    }
   } else {
     limits.x <- c(0, max(data.global[,6]) * 1.05)
   }
 
-  if(limits.x[1] != 0) {
-    .throw_warning("Lower x-axis limit was ", limits.x[1], ", reset to zero")
-    limits.x[1] <- 0
-  }
-
   if ("ylim" %in% names(extraArgs) && !is.null(extraArgs$ylim)) {
     limits.y <- extraArgs$ylim
     .validate_class(limits.y, "numeric", name = "'ylim'")
@@ -934,6 +908,18 @@ plot_AbanicoPlot <- function(
     plot.ratio <- plot.ratio * 1.05
   }
 
+  ## save the original plot parameters and restore them when exiting
+  ## this must be done after all validations have completed, otherwise a
+  ## warning may be generated (#1001) if any validation step fails.
+  if (sum(par()$mfrow) == 2 && sum(par()$mfcol) == 2) {
+    par.default <- .par_defaults()
+  } else {
+    ## this ensures that mfrow/mfcol are not reset when we want to draw
+    ## several plots on one page
+    par.default <- par(c("mar", "mai", "xpd", "cex"))
+  }
+  on.exit(par(par.default), add = TRUE)
+
   ## wrapper functions to deal with rotation
   plot.rot <- function(xlim, ylim, ...) {
     if (!rotate) plot(xlim = xlim, ylim = ylim, ...) else plot(xlim = ylim, ylim = xlim, ...)
@@ -981,32 +967,27 @@ plot_AbanicoPlot <- function(
       between(tick.values.major, min(tick.values.minor), max(tick.values.minor))]
   tick.values.minor <- tick.values.minor[
       between(tick.values.minor, limits.z[1], limits.z[2])]
+  label.z.text <- signif(tick.values.major, 3)
 
-  if(log.z[1]) {
+  if (log.z) {
     tick.values.major[tick.values.major == 0] <- 1
     tick.values.minor[tick.values.minor == 0] <- 1
 
     tick.values.major <- log(tick.values.major)
     tick.values.minor <- log(tick.values.minor)
+    label.z.text <- signif(exp(tick.values.major) - De.add, 3)
   }
 
   ## calculate z-axis radius
   r <- max(sqrt((limits.x[2])^2 + (data.global[,7] * f)^2))
 
-  ## create z-axes labels
-  if(log.z[1]) {
-    label.z.text <- signif(exp(tick.values.major) - De.add, 3)
-  } else {
-    label.z.text <- signif(tick.values.major, 3)
-  }
-
   ## calculate node coordinates for semi-circle
-  ellipse.values <- c(min(ifelse(log.z == TRUE,
+  ellipse.values <- c(min(ifelse(log.z,
                                  log(limits.z[1]),
                                  limits.z[1]),
                           tick.values.major,
                           tick.values.minor),
-                      max(ifelse(log.z == TRUE,
+                      max(ifelse(log.z,
                                  log(limits.z[2]),
                                  limits.z[2]),
                           tick.values.major,
@@ -1025,19 +1006,19 @@ plot_AbanicoPlot <- function(
   stats.data <- matrix(nrow = 3, ncol = 3)
   data.stats <- as.numeric(data.global[,1])
 
-  if("min" %in% stats == TRUE) {
+  if ("min" %in% stats) {
     stats.data[1, 3] <- data.stats[data.stats == min(data.stats)][1]
     stats.data[1, 1] <- data.global[data.stats == stats.data[1, 3], 6][1]
     stats.data[1, 2] <- data.global[data.stats == stats.data[1, 3], 8][1]
   }
 
-  if("max" %in% stats == TRUE) {
+  if ("max" %in% stats) {
     stats.data[2, 3] <- data.stats[data.stats == max(data.stats)][1]
     stats.data[2, 1] <- data.global[data.stats == stats.data[2, 3], 6][1]
     stats.data[2, 2] <- data.global[data.stats == stats.data[2, 3], 8][1]
   }
 
-  if("median" %in% stats == TRUE) {
+  if ("median" %in% stats) {
     stats.data[3, 3] <- data.stats[data.stats == quantile(data.stats, 0.5, type = 3)]
     stats.data[3, 1] <- data.global[data.stats == stats.data[3, 3], 6][1]
     stats.data[3, 2] <- data.global[data.stats == stats.data[3, 3], 8][1]
@@ -1049,10 +1030,8 @@ plot_AbanicoPlot <- function(
   max.ellipse <- max(ellipse[, rotate.idx])
 
   ## re-calculate axes limits if necessary
-  limits.z.x <- range(ellipse[, rotate.idx])
-  limits.z.y <- range(ellipse[, 3 - rotate.idx])
-
   if(!("ylim" %in% names(extraArgs))) {
+    limits.z.y <- range(ellipse[, 3 - rotate.idx])
     if(limits.z.y[1] < 0.66 * limits.y[1]) {
       limits.y[1] <- 1.8 * limits.z.y[1]
     }
@@ -1060,14 +1039,13 @@ plot_AbanicoPlot <- function(
       limits.y[2] <- 1.3 * limits.z.y[2]
     }
 
-    if(rotate == TRUE) {
+    if (rotate) {
       limits.y <- c(-max(abs(limits.y)), max(abs(limits.y)))
     }
   }
   if(!("xlim" %in% names(extraArgs))) {
-    if(limits.z.x[2] > 1.1 * limits.x[2]) {
-      limits.x[2] <- limits.z.x[2]
-    }
+    limits.z.x <- range(ellipse[, rotate.idx])
+    limits.x[2] <- max(limits.z.x[2], limits.z.x)
   }
 
   ## calculate and paste statistical summary
@@ -1102,7 +1080,7 @@ plot_AbanicoPlot <- function(
     De.stats[i,12] <- statistics$kurtosis
 
     ## account for log.z-option
-    if(log.z[1]) {
+    if (log.z) {
       De.stats[i,2:4] <- exp(De.stats[i,2:4]) - De.add
     }
 
@@ -1134,7 +1112,7 @@ plot_AbanicoPlot <- function(
   label.text <- list()
   for (i in 1:length(data)) {
     if (!is.sub)
-      stops <- paste(rep("\n", (i - 1) * length(summary)), collapse = "")
+      stops <- strrep("\n", (i - 1) * length(summary))
 
     summary.text <- character(0)
     for (j in 1:length(summary)) {
@@ -1207,7 +1185,7 @@ plot_AbanicoPlot <- function(
     ## this time we swap x and y limits as we are rotated, then apply some
     ## adjustments to the x positioning
     coords <- .get_keyword_coordinates(legend.pos, limits.y, limits.x)
-    if (!missing(legend.pos) &&
+    if (!is.null(legend.pos) &&
         legend.pos[1] %in% c("topleft", "left", "bottomleft")) {
       coords$pos[1] <- coords$pos[1] + par()$cxy[1] * 7.5
     }
@@ -1216,14 +1194,13 @@ plot_AbanicoPlot <- function(
   }
 
   ## define cartesian plot origins
-  if(rotate == FALSE) {
+  if (!rotate) {
     xy.0 <- c(min(ellipse[,1]) * lostintranslation, min(ellipse[,2]))
   } else {
     xy.0 <- c(min(ellipse[,1]), min(ellipse[,2]) * lostintranslation)
   }
 
   ## calculate coordinates for dispersion polygon overlay
-  y.max.x <- 2 * limits.x[2] / max(data.global[6])
   y.max <- if (!rotate) par()$usr[2] else par()$usr[4]
 
   polygons.x <- c(limits.x[1], limits.x[2], xy.0[rotate.idx], y.max, y.max,
@@ -1232,26 +1209,26 @@ plot_AbanicoPlot <- function(
   for(i in 1:length(data)) {
     if(dispersion == "qr") {
       ci.lo_up <- quantile(data[[i]][, 1], c(0.25, 0.75))
-    } else if(grepl(x = dispersion, pattern = "p") == TRUE) {
+    } else if (grepl("p", dispersion)) {
       ci.plot <- as.numeric(strsplit(x = dispersion,
                                      split = "p")[[1]][2])
       ci.plot <- (100 - ci.plot) / 100
       ci.lo_up <- quantile(data[[i]][, 1], c(ci.plot, 1 - ci.plot))
     } else if(dispersion == "sd") {
-      if(log.z == TRUE) {
+      if (log.z) {
         ci.lo_up <- exp(mean(log(data[[i]][, 1])) + c(-1, 1) * sd(log(data[[i]][, 1])))
       } else {
         ci.lo_up <- mean(data[[i]][, 1]) + c(-1, 1) * sd(data[[i]][, 1])
       }
     } else if(dispersion == "2sd") {
-      if(log.z == TRUE) {
+      if (log.z) {
         ci.lo_up <- exp(mean(log(data[[i]][, 1])) + c(-2, 2) * sd(log(data[[i]][, 1])))
       } else {
         ci.lo_up <- mean(data[[i]][, 1]) + c(-2, 2) * sd(data[[i]][, 1])
       }
     }
 
-    if(log.z == TRUE) {
+    if (log.z) {
       ci.lo_up[which(ci.lo_up < 0)] <- 1
       ci.lo_up <- log(ci.lo_up)
     }
@@ -1358,7 +1335,7 @@ plot_AbanicoPlot <- function(
                                         if (log.z) 100 else 1, 1))
 
     ## optionally, plot 2-sigma-bar
-    if (bar[1] != FALSE) {
+    if (!isFALSE(bar[1])) {
       if (is.logical(bar)) {
         bar <- sapply(data, function(x) x[1, 5])
       } else if (log.z) {
@@ -1429,7 +1406,7 @@ plot_AbanicoPlot <- function(
     }
 
     ## optionally, plot lines for each bar
-    if (lwd[1] > 0 && lty[1] > 0 && bar[1] != FALSE) {
+    if (lwd[1] > 0 && lty[1] > 0 && !isFALSE(bar[1])) {
       for (i in 1:length(data)) {
         z.line <- if (length(bar) == 1) bar[1] else bar[i]
         x2 <- r / sqrt(1 + f^2 * (z.line - z.central.global)^2)
@@ -1443,7 +1420,7 @@ plot_AbanicoPlot <- function(
     }
 
   ## optionally add further lines
-  if (!missing(line) && length(line) > 0) {
+  if (length(line) > 0) {
 
     ## check if line parameters are RLum.Results objects
     if (is.list(line)) {
@@ -1461,11 +1438,11 @@ plot_AbanicoPlot <- function(
       line <- unlist(line)
     if (log.z)
       line <- log(line)
-    if (missing(line.col))
+    if (is.null(line.col))
       line.col <- seq_along(line)
-    if (missing(line.lty))
+    if (is.null(line.lty))
       line.lty <- rep(1, length(line))
-    if (missing(line.label))
+    if (is.null(line.label))
       line.label <- rep("", length(line))
 
     ## calculate line coordinates and further parameters
@@ -1577,6 +1554,7 @@ plot_AbanicoPlot <- function(
     ## remove first tick label (infinity)
     label.x.upper <- label.x.upper[1:(length(x.axis.ticks) - 1)]
 
+  if (length(x.axis.ticks) > 1) {
     axis(side = rotate.idx,
          at = x.axis.ticks[-1],
          labels = label.x.upper,
@@ -1588,6 +1566,7 @@ plot_AbanicoPlot <- function(
                         layout$abanico$font.deco$xtck2)[1],
          col.axis = layout$abanico$colour$xtck2,
          cex.axis = layout$abanico$font.size$xlab2 / 12)
+  }
 
   ## plot y-axis
   if (is.null(extraArgs$yaxt) || extraArgs$yaxt != "n") {
@@ -1599,11 +1578,9 @@ plot_AbanicoPlot <- function(
     cex.axis <- layout$abanico$font.size$ylab / 12
     if (y.axis) {
       char.height <- par()$cxy[2]
-      tick.space <- grDevices::axisTicks(usr = limits.y, log = FALSE)
-      tick.space <- (max(tick.space) - min(tick.space)) / length(tick.space)
 
       ## this comes into play for panel plots, e.g., par(mfrow = c(4,4))
-      if (tick.space < char.height * 1.7) {
+      if (char.height > 4.5 / cex) {
         axis(side = 3 - rotate.idx,
              at = c(-2, 2),
              tcl = -layout$abanico$dimension$ytcl / 200,
@@ -1690,7 +1667,7 @@ plot_AbanicoPlot <- function(
       arrow.x <- data[[i]][, 6]
       arrow.y1 <- data[[i]][, 1] - data[[i]][, 2]
       arrow.y2 <- data[[i]][, 1] + data[[i]][, 2]
-      if (log.z == TRUE) {
+      if (log.z) {
         arrow.y1 <- log(arrow.y1)
         arrow.y2 <- log(arrow.y2)
       }
@@ -1989,7 +1966,7 @@ plot_AbanicoPlot <- function(
   }
 
   ## optionally add legend content
-  if (!missing(legend)) {
+  if (!is.null(legend)) {
     ## store and change font familiy
     par.family <- par()$family
     par(family = layout$abanico$font.type$legend)
@@ -2007,7 +1984,7 @@ plot_AbanicoPlot <- function(
            text.col = value.dot,
            text.font = which(c("normal", "bold", "italic", "bold italic") ==
                              layout$abanico$font.deco$legend)[1],
-           cex = cex * layout$abanico$font.size$legend / 12,
+           cex = layout$abanico$font.size$legend / 12,
            bty = "n")
 
     ## restore font family
@@ -2037,8 +2014,7 @@ plot_AbanicoPlot <- function(
              font = which(c("normal", "bold", "italic", "bold italic") ==
                             layout$abanico$font.deco$summary)[1],
              cex = layout$abanico$font.size$summary / 12)
-    } else {
-        if (mtext == "") {
+    } else if (mtext == "") {
           mtext(side = 3,
                 line = (shift.lines - 1 + add.shift - i) *
                   layout$abanico$dimension$summary / 100 ,
@@ -2048,7 +2024,6 @@ plot_AbanicoPlot <- function(
                 font = which(c("normal", "bold", "italic", "bold italic") ==
                                layout$abanico$font.deco$summary)[1],
                 cex = cex * layout$abanico$font.size$summary / 12)
-        }
     }
   }
 
@@ -2224,9 +2199,6 @@ plot_AbanicoPlot <- function(
     return(IAP)
   }
 
-  ## restore initial cex
-  par(cex = cex_old)
-
   ## create and return numeric output
   invisible(plot.output)
 }
