@@ -103,7 +103,7 @@ if(inherits(object, "list")){
   plot_settings <- list(...)
 
   ## expand input arguments
-  if("main" %in% names(list(...))){
+  if ("main" %in% ...names()) {
     main <- .listify(list(...)[["main"]], length(object))
 
     ##filter main from the ... argument list otherwise we will have a collusion
@@ -141,13 +141,11 @@ if(inherits(object, "list")){
   ## set limit
   if (is.null(sel_curves)) {
     sel_curves <- 1:length(object@data$Formula)
-  } else {
-      if(min(sel_curves) < 1 ||
+  } else if (min(sel_curves) < 1 ||
          max(sel_curves) > length(object@data$Formula) ||
          length(sel_curves) > length(object@data$Formula)){
         .throw_warning("'sel_curves' out of bounds, reset to full dataset")
         sel_curves <- 1:length(object@data$Formula)
-      }
   }
 
     ## check the whether the fitting was all the same
@@ -158,10 +156,6 @@ if(inherits(object, "list")){
     ##get DRC
     DRC <- object@data$Formula[sel_curves]
 
-    ## check for OTOR fit option (we can only do all )
-    if(all(object@data$data[["Fit"]] %in% c("OTOR", "OTORX")))
-      W <- lamW::lambertW0
-
   ## get limits for each set
   idx.natural <- which(object@data$LnLxTnTx.table[["Name"]] == "Natural")
   dataset_limits <- cbind(idx.natural,
@@ -274,7 +268,7 @@ if(inherits(object, "list")){
   }
 
   ## Results -------------------------------------------------------------------
-  results <- set_RLum(
+  set_RLum(
     class = "RLum.Results",
     data = list(
       results = data.frame(
@@ -287,7 +281,4 @@ if(inherits(object, "list")){
       call = sys.call(),
       args = as.list(sys.call())[-1])
   )
-
-  ## Return value --------------------------------------------------------------
-  return(results)
 }
