@@ -32,7 +32,7 @@
 #' @return
 #' A plot (or a series of plots) is produced.
 #'
-#' @section Function version: 1.0.7
+#' @section Function version: 1.0.8
 #'
 #' @author
 #' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)\cr
@@ -134,15 +134,6 @@ plot_DoseResponseCurve <- function(
             c(0, xmax)
           }
 
-  ## pch lookup table
-  reg_points_pch <- rep(19, nrow(xy))
-
-    ## correct repeated an zero
-    if(mode == "interpolation") {
-      reg_points_pch[duplicated(xy[[1]])] <- 2
-      reg_points_pch[xy[[1]] == 0] <-  1
-    }
-
   ## set plot settings
   plot_settings <- modifyList(
     x = list(
@@ -151,22 +142,19 @@ plot_DoseResponseCurve <- function(
       ylab = if (mode == "interpolation") expression(L[x]/T[x]) else "Luminescence [a.u.]",
       ylim = ylim,
       xlim = xlim,
+      mar = c(4, 3, 3, 1),
+      mgp = c(2, 0.7, 0),
+      tcl = -0.4,
       cex = 1,
-      mtext = if (mode != "alternate") {
-          substitute(
-            D[e] == De,
-            list(De = paste(
-              round(
-                abs(De), digits = 2), "\u00B1",
-              format(De.Error, scientific = TRUE, digits = 2),
-              " | fit: ", fit.args$fit.method)))
-        } else {
-          ""
-        },
+      mtext = if (mode != "alternate")
+                substitute(D[e] == De,
+                           list(De = sprintf("%.2f \uB1 %.1e  |  fit: %s",
+                                             abs(De), De.Error, fit.args$fit.method)))
+              else "",
       log = "",
       legend = TRUE,
       legend.pos = if (mode == "interpolation") "topleft" else "bottomright",
-      reg_points_pch = reg_points_pch,
+      reg_points_pch = c(19, 1, 2), # point, point 0, point repeated
       density_polygon = TRUE,
       density_polygon_col = rgb(1,0,0,0.2),
       density_rug = TRUE,
@@ -177,9 +165,8 @@ plot_DoseResponseCurve <- function(
 
   if (plot_settings$log != "") {
     if (mode == "extrapolation") {
-      .throw_message("[plot_DoseResponseCurve] No logarithmic transformation ",
-                     "allowed on a fit obtained with mode = 'extrapolation', ",
-                     "'log' reset to ''")
+      .throw_message("Logarithmic transformation not allowed on an object ",
+                     "fitted with mode = 'extrapolation', 'log' reset to ''")
       plot_settings$log <- ""
     } else {
       ## if we want to apply a log-transform on x and the first time point
@@ -194,18 +181,29 @@ plot_DoseResponseCurve <- function(
     }
   }
 
+  if (length(plot_settings$reg_points_pch) < 3) {
+    plot_settings$reg_points_pch <- c(19, 1, 2)
+    .throw_message("'reg_points_pch' should have length 3 (for point, point 0, ",
+                   "point repeated), 'reg_points_pch' reset to c(19, 1, 2)")
+  }
+
   ## Main plots -------------------------------------------------------------
 
   ## open plot area
-  par.default <- par("cex", "mar", "mgp")
-  on.exit(par(par.default), add = TRUE)
 
   if (plot_extended && !plot_singlePanels) {
-    ## append the parameters modified by layout()
-    par.default <- c(par.default, par("mfrow", "mfcol"))
+    par.default <- .par_defaults()
     graphics::layout(matrix(c(1, 1, 1, 1, 2, 3), 3, 2, byrow = TRUE), respect = TRUE)
-    par(cex = 0.8 * plot_settings$cex, mar = c(3, 3, 3, 1), mgp = c(2, 1, 0))
+    par(cex = 0.8 * plot_settings$cex, mar = c(3, 3, 3, 1))
+  } else {
+    ## only restore those we are changing, to avoid resetting all graphical
+    ## parameters if we were restoring also mfrow/mfcol, as that would affect
+    ## the plots generated by analyse_SAR.CWOSL() and analyse_pIRIRSequence()
+    par.default <- par(c("cex", "mar", "mgp"))
+    par(mar = plot_settings$mar)
   }
+  on.exit(par(par.default), add = TRUE)
+  par(mgp = plot_settings$mgp, tcl = plot_settings$tcl)
 
   #PLOT		#Plot input values
   ##Make selection to support manual number of reg points input
@@ -214,7 +212,7 @@ plot_DoseResponseCurve <- function(
       ylim = plot_settings$ylim,
       xlim = plot_settings$xlim,
       log = plot_settings$log,
-      pch = plot_settings$reg_points_pch,
+      pch = plot_settings$reg_points_pch[1],
       xlab = plot_settings$xlab,
       ylab = plot_settings$ylab,
       frame.plot = plot_settings$box[1]
@@ -273,10 +271,7 @@ plot_DoseResponseCurve <- function(
     points(
         x = xy[idx.rep, 1],
         y = xy[idx.rep, 2],
-        pch = if(is.na(plot_settings$reg_points_pch[2]))
-                plot_settings$reg_points_pch[1]
-              else
-                plot_settings$reg_points_pch[2])
+        pch = plot_settings$reg_points_pch[3])
 
        ## LINES	#Insert Ln/Tn
     if (mode == "interpolation") {
@@ -345,16 +340,12 @@ plot_DoseResponseCurve <- function(
           rm(tmp_x, tmp_y, density_De)
       }
 
-
       ## reg Point 0
       idx.0 <- which(xy == 0)
       points(
         x = xy[idx.0, 1],
         y = xy[idx.0, 2],
-        pch = if(is.na(plot_settings$reg_points_pch[3]))
-               plot_settings$reg_points_pch[1]
-              else
-               plot_settings$reg_points_pch[3],
+        pch = plot_settings$reg_points_pch[2],
         cex = 1.5)
 
       ## y-error bar
@@ -363,11 +354,9 @@ plot_DoseResponseCurve <- function(
       if(plot_settings$density_rug[1])
         suppressWarnings(graphics::rug(x = x.natural, side = 3))
 
-    } else if (mode == "extrapolation"){
-      if (!is.na(De)) {
+    } else if (mode == "extrapolation" && !is.na(De)) {
         abline(v = De, lty = 2, col = col[2])
         lines(x = c(0,De), y = c(0,0), lty = 2, col = col[2])
-      }
     }
 
     ## insert fit and result
@@ -391,18 +380,17 @@ plot_DoseResponseCurve <- function(
     if(plot_settings$legend) {
       legend(
           plot_settings$legend.pos,
-          legend = if (mode == "interpolation")
-                     c("REG point", "REG point 0", "REG point repeated")
-                   else
-                     c("Dose point", "Dose point 0", "Dose point rep."),
-          pch = unique(plot_settings$reg_points_pch),
+          legend = paste(ifelse(mode == "interpolation", "REG", "Dose"),
+                         c("point", "point 0", "point repeated")),
+          pch = plot_settings$reg_points_pch,
           cex = 0.7,
           bty = "n")
     }
 
     if (plot_extended) {
       ## decrease spacing between axis labels and plots
-      par(mar = c(4, 3, ifelse(plot_singlePanels, 2, 3), 1), mgp = c(2, 1, 0))
+      par(mar = c(4, 3, ifelse(plot_singlePanels, 1.5, 2.5), 1),
+          mgp = c(1.5, 0.7, 0), tcl = -0.4)
 
       ## Histogram ----------------------------------------------------------
       if (!plot_singlePanels)
@@ -486,6 +474,7 @@ plot_DoseResponseCurve <- function(
           try(
             mtext(
               side = 3,
+              line = ifelse(plot_extended && !plot_singlePanels, -0.2, -0.3),
               text = De.expr,
               cex = 0.6 * par("cex")),
             silent = TRUE)
@@ -513,7 +502,7 @@ plot_DoseResponseCurve <- function(
               cex.main = 0.8,
               type = "o",
               pch = 20)
-          lines(c(1, length(sample[, "TnTx"])), c(1, 1), lty = 2, col = "gray")
+          lines(c(0, nrow(sample) + 1), c(1, 1), lty = 2, col = "gray")
         } else {
           plot(NA, NA, xlim = c(0, 10), ylim = c(0, 10),
                axes = FALSE, xlab = "", ylab = "",
