@@ -143,24 +143,25 @@ plot_Histogram <- function(
   }
 
   ## we don't check the second column, as that can be NA
-  .validate_class(data[, 1], "numeric", name = "All columns of 'data'")
+  .validate_class(data[, 1], c("numeric", "integer"),
+                  name = "All columns of 'data'")
 
   .validate_class(cex.global, "numeric")
   .validate_class(summary, "character")
-  .validate_class(summary.pos, c("numeric", "character"))
   if (is.numeric(summary.pos)) {
     .validate_length(summary.pos, 2)
   }
   else {
-    .validate_args(summary.pos, c("sub", "left", "center", "right",
-                                  "topleft", "top", "topright",
-                                  "bottomleft", "bottom", "bottomright"))
+    summary.pos <- .validate_args(summary.pos,
+                                  c("sub", "left", "center", "right",
+                                    "topleft", "top", "topright",
+                                    "bottomleft", "bottom", "bottomright"))
   }
   .validate_logical_scalar(na.rm)
   .validate_logical_scalar(se)
   .validate_logical_scalar(rug)
   .validate_logical_scalar(normal_curve)
-  .validate_length(colour, 4)
+  .validate_class(colour, "character", length = 4)
 
   ## handle error-free data sets
   if (length(data) < 2 || all(is.na(data[, 2]))) {
@@ -174,10 +175,12 @@ plot_Histogram <- function(
   extraArgs <- list(...)
 
   ## optionally, count and exclude NA values and print result
-  if(na.rm == TRUE) {
+  if (na.rm) {
     n.NA <- sum(is.na(data[,1]))
     if (n.NA > 0) {
-      cat(sprintf("%d NA value%s excluded\n", n.NA, ifelse(n.NA > 1, "s", "")))
+      .throw_message(sprintf("%d NA value%s excluded\n",
+                             n.NA, ifelse(n.NA > 1, "s", "")),
+                     error = FALSE)
       data <- data[!is.na(data[, 1]), ]
     }
   }
@@ -195,7 +198,7 @@ plot_Histogram <- function(
 
   if("ylim" %in% names(extraArgs)) {
     ylim.plot <- extraArgs$ylim
-    .validate_length(ylim.plot, 4, name = "'ylim'")
+    .validate_class(ylim.plot, "numeric", length = 4, name = "'ylim'")
   } else {
     H.lim <- hist(data[,1],
                   breaks = breaks.plot,
@@ -218,6 +221,8 @@ plot_Histogram <- function(
   ), extraArgs)
 
   ## Set plot area format
+  par.default <- .par_defaults()
+  on.exit(par(par.default), add = TRUE)
   par(mar = c(4.5, 4.5, 4.5, if (se) 4.5 else 1),
       cex = cex.global)
 
@@ -239,10 +244,9 @@ plot_Histogram <- function(
   }
 
   ## Optionally, add a normal curve based on the data -------------------------
-  if(normal_curve == TRUE){
-    ## cheat the R check routine, tztztz how neat
+  if (normal_curve) {
+    ## silence notes raised by R CMD check
     x <- NULL
-    rm(x)
 
     ## add normal distribution curve
     curve(dnorm(x,
@@ -319,14 +323,13 @@ plot_Histogram <- function(
            "")
   }
 
-  ## initialize list with a dummy element, it will be removed afterwards
-  label.text <- list(NA)
-
+  ## initialize list
+  label.text <- NULL
   is.sub <- summary.pos[1] == "sub"
   stops <- NULL
   for (i in 1:length(data)) {
     if (!is.sub)
-      stops <- paste(rep("\n", (i - 1) * length(summary)), collapse = "")
+      stops <- strrep("\n", (i - 1) * length(summary))
 
     summary.text <- character(0)
     for (j in 1:length(summary)) {
@@ -359,15 +362,12 @@ plot_Histogram <- function(
           .summary_line("serel.weighted", summary[j], De.stats[i, 18], sep = is.sub,
                         label = "rel. weighted se"))
     }
-    label.text[[length(label.text) + 1]] <- paste0(
+    label.text[[i]] <- paste0(
         if (is.sub) "" else stops,
         paste(summary.text, collapse = ""),
         stops)
   }
 
-  ## remove dummy list element
-  label.text[[1]] <- NULL
-
   ## remove outer vertical lines from string
   if (is.sub) {
     for (i in seq_along(label.text)) {
@@ -378,7 +378,7 @@ plot_Histogram <- function(
   }
 
   ## convert keywords into summary placement coordinates
-  coords <- .get_keyword_coordinates(summary.pos, settings$xlim, ylim.plot)
+  coords <- .get_keyword_coordinates(summary.pos, settings$xlim, ylim.plot[1:2])
   summary.pos <- coords$pos
   summary.adj <- coords$adj
 
@@ -391,20 +391,18 @@ plot_Histogram <- function(
            labels = label.text[[i]],
            col = colour[2],
            cex = 0.8)
-    } else {
-      if(mtext == "") {
+    } else if (mtext == "") {
         mtext(side = 3,
               line = 1 - i,
               text = label.text[[i]],
               col = colour[2],
               cex = cex.global * 0.8)
-      }
     }
   }
 
   ## Optionally, add standard error plot --------------------------------------
 
-  if(se == TRUE) {
+  if (se) {
     par(new = TRUE)
     plot.data <- data[!is.na(data[,2]),]
 
@@ -428,8 +426,6 @@ plot_Histogram <- function(
           side = 4,
           line = 3,
           cex = cex.global)
-
-    #    par(new = FALSE)
   }
 
   ## Optionally add user-defined mtext
@@ -449,7 +445,7 @@ plot_Histogram <- function(
     data <- as.data.frame(data)
     colnames(data) <- c("x", "y")
     x <- y <- NULL # suffice CRAN check for no visible binding
-    if (length(grep("paste", as.character(settings$xlab))) > 0)
+    if (any(grepl("paste", as.character(settings$xlab), fixed = TRUE)))
       settings$xlab <- "Equivalent dose [Gy]"
 
     ## create plots ----
@@ -468,10 +464,8 @@ plot_Histogram <- function(
 
     # normal curve ----
     if (normal_curve) {
-
       density.curve <- density(data$x)
       normal.curve <- data.frame(x = density.curve$x, y = density.curve$y)
-
       hist <- plotly::add_trace(hist, data = normal.curve, x = ~x, y = ~y,
                                 inherit = FALSE,
                                 type = "scatter", mode = "lines",
