@@ -142,7 +142,7 @@ plot_NRt <- function(data, log = FALSE, smooth = c("none", "spline", "rmean"), k
     else
       .throw_error("'data' doesn't contain the expected type of elements")
   }
-  else if (inherits(data, "data.frame") || inherits(data, "matrix")) {
+  else if (inherits(data, c("data.frame", "matrix"))) {
     if (ncol(data) < 3)
       .throw_error("'data' contains only curve data for the natural signal")
     if (is.matrix(data))
@@ -229,6 +229,8 @@ plot_NRt <- function(data, log = FALSE, smooth = c("none", "spline", "rmean"), k
   settings <- modifyList(settings, list(...))
 
   ## PLOTTING ----------
+  par.default <- .par_defaults()
+  on.exit(par(par.default), add = TRUE)
 
   # set graphical parameter
   par(cex = settings$cex)
