@@ -103,7 +103,7 @@ write_R2BIN <- function(
   ##set supported BIN format version
   VERSION.supported <- as.raw(c(3, 4, 5, 6, 7, 8))
 
-  ## Integrity tests --------------------------------------------------------
+  ## Integrity checks -------------------------------------------------------
 
   .validate_class(object, "Risoe.BINfileData")
   .validate_class(file, "character")
@@ -121,8 +121,7 @@ write_R2BIN <- function(
 
   # Check Risoe.BINfileData Struture ----------------------------------------
   ##check whether the BIN-file DATA slot contains more than 9999 records; needs to be run all the time
-  temp_check <- vapply(object@DATA, function(x) length(x) > 9999,
-                       FUN.VALUE = logical(1))
+  temp_check <- lengths(object@DATA) > 9999L
 
   ##force compatibility
   if(compatibility.mode && any(temp_check)){
@@ -168,7 +167,7 @@ write_R2BIN <- function(
   }
 
   if(any(temp_check))
-    .throw_error(length(which(temp_check)), " out of ", length(temp_check),
+    .throw_error(sum(temp_check), " out of ", length(temp_check),
                  " records contain more than 9,999 data points. ",
                  "This violates the BIN/BINX-file definition")
 
@@ -176,18 +175,18 @@ write_R2BIN <- function(
   rm(temp_check)
 
   ## UTF-8 conversion
-  object@METADATA[["SAMPLE"]] <- base::iconv(object@METADATA[["SAMPLE"]], "latin1", "ASCII", sub="_")
-  object@METADATA[["COMMENT"]] <- base::iconv(object@METADATA[["COMMENT"]], "latin1", "ASCII", sub="_")
-  object@METADATA[["FNAME"]] <- base::iconv(object@METADATA[["FNAME"]], "latin1", "ASCII", sub="_")
-  object@METADATA[["USER"]] <- base::iconv(object@METADATA[["USER"]], "latin1", "ASCII", sub="_")
-  object@METADATA[["SEQUENCE"]] <- base::iconv(object@METADATA[["SEQUENCE"]], "latin1", "ASCII", sub="_")
+  conv <- function(x) base::iconv(x, "latin1", "ASCII", sub = "_")
+  object@METADATA[["SAMPLE"]] <- conv(object@METADATA[["SAMPLE"]])
+  object@METADATA[["COMMENT"]] <- conv(object@METADATA[["COMMENT"]])
+  object@METADATA[["FNAME"]] <- conv(object@METADATA[["FNAME"]])
+  object@METADATA[["USER"]] <- conv(object@METADATA[["USER"]])
+  object@METADATA[["SEQUENCE"]] <- conv(object@METADATA[["SEQUENCE"]])
 
   ##VERSION
   ##If missing version argument set to the highest value
   if(missing(version)){
     version <- as.raw(max(as.numeric(object@METADATA[,"VERSION"])))
     version.original <- version
-
   }else{
     version.original <- as.raw(max(as.numeric(object@METADATA[,"VERSION"])))
     version <- as.raw(version)
@@ -243,10 +242,7 @@ write_R2BIN <- function(
   }
 
   ## enables compatibility to the Analyst as the max value for POSITION becomes 48
-  if(compatibility.mode){
-    ##just do if position values > 48
-    if(max(object@METADATA[,"POSITION"])>48){
-
+  if (compatibility.mode && max(object@METADATA[, "POSITION"]) > 48) {
       ##grep relevant IDs
       temp.POSITION48.id <- which(object@METADATA[,"POSITION"]>48)
 
@@ -263,7 +259,6 @@ write_R2BIN <- function(
                                                   "OP:", object@METADATA$POSITION[idx])
         object@METADATA[idx, "POSITION"] <- temp.POSITION48.new[i]
       }
-    }
   }
 
   ##COMMENT
@@ -314,7 +309,7 @@ write_R2BIN <- function(
   ##TAG and SEL
   ##in TAG information on the SEL are storred, here the values are copied to TAG
   ##before export
-  object@METADATA[,"TAG"] <- ifelse(object@METADATA[,"SEL"] == TRUE, 1, 0)
+  object@METADATA[, "TAG"] <- as.integer(object@METADATA[, "SEL"])
 
   # SET FILE AND VALUES -----------------------------------------------------
   con <- file(file, "wb")
@@ -419,7 +414,7 @@ write_R2BIN <- function(
       }
 
       ##DATE
-      writeBin(as.integer(6),
+      writeBin(6L,
                con,
                size = 1 ,
                endian="little")
@@ -531,8 +526,7 @@ write_R2BIN <- function(
 
       ##avoid problems with empty sample names
       if(SAMPLE_SIZE == 0){
-
-        SAMPLE_SIZE <- as.integer(2)
+        SAMPLE_SIZE <- 2L
         object@METADATA[ID,"SAMPLE"] <- "  "
       }
 
@@ -559,7 +553,7 @@ write_R2BIN <- function(
 
       ##avoid problems with empty comments
       if(COMMENT_SIZE == 0){
-        COMMENT_SIZE <- as.integer(2)
+        COMMENT_SIZE <- 2L
         object@METADATA[ID,"COMMENT"] <- "  "
       }
 
@@ -739,7 +733,7 @@ write_R2BIN <- function(
   }
   ## ====================================================
   ## version > 06
-  if(version == 05 | version == 06 | version == 07 | version == 08){
+  if (version == 05 || version == 06 || version == 07 || version == 08) {
     ##start loop for export BIN data
     while(ID<=n.records) {
       ##VERSION
@@ -786,8 +780,7 @@ write_R2BIN <- function(
 
       ##avoid problems with empty sample names
       if(SAMPLE_SIZE == 0){
-
-        SAMPLE_SIZE <- as.integer(2)
+        SAMPLE_SIZE <- 2L
         object@METADATA[ID,"SAMPLE"] <- "  "
       }
 
@@ -796,7 +789,6 @@ write_R2BIN <- function(
                size = 1,
                endian="little")
 
-
       writeChar(as.character(object@METADATA[ID,"SAMPLE"]),
                 con,
                 nchars = SAMPLE_SIZE,
@@ -815,7 +807,7 @@ write_R2BIN <- function(
 
       ##avoid problems with empty comments
       if(COMMENT_SIZE == 0){
-        COMMENT_SIZE <- as.integer(2)
+        COMMENT_SIZE <- 2L
         object@METADATA[ID,"COMMENT"] <- "  "
       }
 
@@ -847,8 +839,8 @@ write_R2BIN <- function(
       ##FNAME
       FNAME_SIZE <- as.integer(nchar(as.character(object@METADATA[ID,"FNAME"]), type="bytes"))
 
-        ##correct for case that this is of 0 length
-        if(is.na(FNAME_SIZE) || length(FNAME_SIZE) == 0){FNAME_SIZE <- as.integer(0)}
+      ## correct for case that this is of 0 length
+      if (is.na(FNAME_SIZE) || length(FNAME_SIZE) == 0) FNAME_SIZE <- 0L
 
       writeBin(FNAME_SIZE,
                con,
@@ -915,7 +907,7 @@ write_R2BIN <- function(
       }
 
       ##DATE
-      writeBin(as.integer(6),
+      writeBin(6L,
                con,
                size = 1 ,
                endian="little")
