@@ -17,6 +17,10 @@ test_that("input validation", {
   expect_error(Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, dtype = 10:12),
                "'dtype' contains invalid dtypes, valid dtypes are: 'Natural'")
 
+  risoe <- set_Risoe.BINfileData(METADATA = data.frame(ID = 1, POSITION = 0))
+  expect_error(Risoe.BINfileData2RLum.Analysis(risoe),
+               "'object' has missing columns in METADATA: 'GRAIN', 'RUN', 'SET'")
+
   expect_warning(Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, pos = 1:30),
                  "Invalid position number skipped")
   expect_warning(Risoe.BINfileData2RLum.Analysis(CWOSL.SAR.Data, grain = 1:10),
@@ -59,10 +63,9 @@ test_that("check functionality", {
                  "Invalid position number skipped: 0")
 
   ## reading an object with fields set to zero
-  zero <- set_Risoe.BINfileData(METADATA = data.frame(ID = 1, VERSION = 0,
-                                                      POSITION = 0, GRAIN = 0),
-                                DATA = list(),
-                                .RESERVED = list())
+  zero <- set_Risoe.BINfileData(METADATA = data.frame(ID = 1, POSITION = 0,
+                                                      GRAIN = 0, RUN = 0, SET = 0,
+                                                      LTYPE = 0, DTYPE = 0))
   expect_message(res <- Risoe.BINfileData2RLum.Analysis(zero),
                  "Empty Risoe.BINfileData object detected")
   expect_s4_class(res, "RLum.Analysis")
