@@ -1,5 +1,6 @@
 ## load data
 data(ExampleData.Al2O3C, envir = environment())
+osl <- get_RLum(data_CrossTalk, recordType = "OSL", drop = FALSE)
 
 test_that("input validation", {
   skip_on_cran()
@@ -27,7 +28,7 @@ test_that("input validation", {
                "'irradiation_time_correction' should have length 2")
   expect_error(analyse_Al2O3C_Measurement(data_CrossTalk,
                                           irradiation = set_RLum("RLum.Results")),
-               "was created by an unsupported function")
+               "'irradiation_time_correction' has an unsupported originator")
   expect_error(analyse_Al2O3C_Measurement(data_CrossTalk,
                                           irradiation_time_correction = "a"),
                "should be of class 'RLum.Results', 'numeric' or NULL")
@@ -39,11 +40,16 @@ test_that("input validation", {
                "'cross_talk_correction' should have length 3")
   expect_error(analyse_Al2O3C_Measurement(data_CrossTalk,
                                           cross_talk_correction = set_RLum("RLum.Results")),
-               "was created by an unsupported function")
+               "'cross_talk_correction' has an unsupported originator")
 
   expect_warning(Luminescence:::.warningCatcher(
                                      analyse_Al2O3C_Measurement(object = data_CrossTalk, signal_integral = 1000)))
   })
+
+  data(ExampleData.RF70Curves, envir = environment())
+  expect_warning(expect_error(analyse_Al2O3C_Measurement(RF70Curves),
+                              "No records with recordType 'OSL (UVVIS)'", fixed = TRUE),
+                 "This request produced an empty list of records")
 })
 
 test_that("check functionality", {
@@ -68,33 +74,40 @@ test_that("check functionality", {
                                            dose_points = list(3)))
 
   ## tests without TL curves
-  temp <- get_RLum(data_CrossTalk, recordType = "OSL", drop = FALSE)
   SW({
-  expect_s4_class(analyse_Al2O3C_Measurement(temp),
-                  "RLum.Results")
-  expect_output(analyse_Al2O3C_Measurement(temp, travel_dosimeter = 2),
+  expect_output(analyse_Al2O3C_Measurement(osl, travel_dosimeter = 2),
                 "travel dosimeter correction applied")
-  expect_message(analyse_Al2O3C_Measurement(temp, travel_dosimeter = 1:2),
+  expect_message(analyse_Al2O3C_Measurement(osl, travel_dosimeter = 1:2),
                  "'travel_dosimeter' specifies every position")
-  expect_message(analyse_Al2O3C_Measurement(temp, travel_dosimeter = 2000),
+  expect_message(analyse_Al2O3C_Measurement(osl, travel_dosimeter = 2000),
                  "Invalid position in 'travel_dosimeter', nothing corrected")
   })
 
   ## irradiation_time_correction
   it.corr <- analyse_Al2O3C_ITC(data_ITC, verbose = FALSE)
-  analyse_Al2O3C_Measurement(temp, irradiation_time_correction = list(it.corr),
+  analyse_Al2O3C_Measurement(osl, irradiation_time_correction = list(it.corr),
                              plot = 1, verbose = FALSE)
 
   ## cross_talk_correction
   ct.corr <- analyse_Al2O3C_CrossTalk(data_CrossTalk)
-  analyse_Al2O3C_Measurement(temp, cross_talk_correction = list(ct.corr),
+  analyse_Al2O3C_Measurement(osl, cross_talk_correction = list(ct.corr),
                              plot = FALSE, verbose = FALSE)
-  expect_message(analyse_Al2O3C_Measurement(temp, travel_dosimeter = 1:2,
+  expect_message(analyse_Al2O3C_Measurement(osl, travel_dosimeter = 1:2,
                                             cross_talk_correction = c(-2e-4, -3e-4, 0),
                                             plot = FALSE, verbose = FALSE),
                  "'travel_dosimeter' specifies every position")
 })
 
+test_that("graphical snapshot tests", {
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+
+  SW({
+  vdiffr::expect_doppelganger("defaults",
+                              analyse_Al2O3C_Measurement(osl[2]))
+  })
+})
+
 test_that("more coverage", {
   skip_on_cran()
 
