@@ -23,7 +23,7 @@ test_that("input validation", {
                            bg.subtraction = "error"),
                "'bg.subtraction' should be one of 'polynomial', 'linear', 'channel'")
   expect_error(fit_LMCurve(values.curve, n.components = "error"),
-               "'n.components' should be a positive integer scalar")
+               "'n.components' should be a single positive integer value")
   expect_error(fit_LMCurve(values.curve, input.dataType = "error"),
                "'input.dataType' should be one of 'LM' or 'pLM'")
   expect_error(fit_LMCurve(
@@ -121,7 +121,6 @@ test_that("snapshot tests", {
 test_that("graphical snapshot tests", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
-  testthat::skip_if_not(getRversion() >= "4.4.0")
 
   SW({
   vdiffr::expect_doppelganger("default",
