@@ -16,7 +16,7 @@ test_that("input validation", {
   expect_error(fit_OSLLifeTimes(matrix()),
                "'object' should have at least two columns")
   expect_error(fit_OSLLifeTimes(ExampleData.TR_OSL, n.components = -1),
-               "'n.components' should be a positive integer scalar")
+               "'n.components' should be a single positive integer value")
   expect_error(fit_OSLLifeTimes(ExampleData.TR_OSL, signal_range = FALSE),
                "'signal_range' should be of class 'numeric'")
 
@@ -130,21 +130,6 @@ test_that("check functionality", {
     tolerance = snapshot.tolerance)
   })
 
-  ##warning for log
-  expect_warning(expect_warning(
-      fit_OSLLifeTimes(
-          object = temp_mat,
-          verbose = FALSE,
-          plot = TRUE,
-          plot_simple = TRUE,
-          log = list("xy"),
-          lty = 1,
-          col = 1,
-          n.components = 1),
-      "log-scale requires x-values > 0, set min xlim to 0.01"),
-      "log-scale requires y-values > 0, set min ylim to 1.69e+10",
-      fixed = TRUE)
-
   SW({
   expect_message(fit_OSLLifeTimes(temp_mat[1:10, ]),
                  "The fitting was not successful, consider trying again")
@@ -156,4 +141,42 @@ test_that("check functionality", {
       verbose = FALSE,
       plot = FALSE),
       tolerance = 1.5e-5)
+
+  expect_warning(fit_OSLLifeTimes(
+    object = ExampleData.TR_OSL,
+    plot = FALSE,
+    verbose = FALSE,
+    method_control = list(seed = 100, DEoptim.itermax = 15),
+    n.components = 1),
+    "Fitting failed: singular gradient matrix at initial parameter estimates")
+})
+
+test_that("graphical snapshot tests", {
+  testthat::skip_on_cran()
+  testthat::skip_if_not_installed("vdiffr")
+
+  set.seed(1)
+
+  SW({
+  vdiffr::expect_doppelganger("1 comp",
+                              fit_OSLLifeTimes(
+                                  object = ExampleData.TR_OSL,
+                                  method_control = list(DEoptim.itermax = 15),
+                                  n.components = 1))
+
+  expect_warning(expect_warning(
+      vdiffr::expect_doppelganger("log xy",
+                                  fit_OSLLifeTimes(
+                                      object = temp_mat,
+                                      verbose = FALSE,
+                                      plot = TRUE,
+                                      plot_simple = TRUE,
+                                      log = list("xy"),
+                                      lty = 1,
+                                      col = 1,
+                                      n.components = 1)),
+      "log-scale requires x-values > 0, set min xlim to 0.01"),
+      "log-scale requires y-values > 0, set min ylim to 1.69e+10",
+      fixed = TRUE)
+  })
 })
