@@ -1,3 +1,4 @@
+## load data
 data(ExampleData.DeValues, envir = environment())
 res <- calc_CentralDose(ExampleData.DeValues$CA1,
                         plot = FALSE, verbose = FALSE)
@@ -6,9 +7,11 @@ test_that("input validation", {
   testthat::skip_on_cran()
 
   expect_error(merge_RLum.Results("error"),
-               "'objects' has to be of type 'list'")
+               "'objects' should be of class 'list'")
   expect_error(merge_RLum.Results(list(res, "error")),
-               "All objects to be merged must have type 'RLum.Results'")
+               "All elements of 'object' should be of class 'RLum.Results'")
+  expect_message(expect_null(merge_RLum.Results(list())),
+                 "'objects' contains no data, NULL returned")
 
   res2 <- res
   res2@originator <- "unknown"
@@ -21,20 +24,19 @@ test_that("input validation", {
                "Objects cannot be merged, different number of columns")
 })
 
-test_that("Merge RLum.Results", {
+test_that("check functionality", {
   testthat::skip_on_cran()
 
-  ## check whether arguments are retained
+  set.seed(1)
   a <- array(runif(300, 0,255), c(10,10,3))
   roi <- matrix(c(2.,4,2,5,6,7,3,1,1), ncol = 3)
-  t <-
-    expect_s4_class(merge_RLum.Results(lapply(list(roi, roi, roi), function(x)
-      extract_ROI(a, x))), "RLum.Results")
-
-  expect_length(names(attributes(t@data$roi_summary)), 4)
-
-  a <- merge_RLum.Results(list(res, res))
-  expect_s3_class(a@data$summary, "data.frame")
+  expect_snapshot_RLum(merge_RLum.Results(lapply(list(roi, roi, roi),
+                                                 function(x) extract_ROI(a, x))))
 
+  expect_snapshot_RLum(merge_RLum.Results(list(res, res)))
 
+  empty <- set_RLum("RLum.Results")
+  expect_snapshot_RLum(merge_RLum.Results(list(empty)))
+  expect_s4_class(merge_RLum.Results(list(empty, empty)),
+                  "RLum.Results")
 })
