@@ -4,6 +4,8 @@ set.seed(1)
 fit <- fit_DoseResponseCurve(LxTxData, verbose = FALSE)
 fit.extra.gok <- fit_DoseResponseCurve(LxTxData, mode = "extrapolation",
                                        fit.method = "GOK", verbose = FALSE)
+fit.alt <- fit_DoseResponseCurve(LxTxData, mode = "alternate",
+                                 verbose = FALSE)
 
 test_that("input validation", {
   testthat::skip_on_cran()
@@ -21,7 +23,10 @@ test_that("input validation", {
   expect_error(
       plot_DoseResponseCurve(fit, verbose = "error"),
       "'verbose' should be a single logical value")
-})
+  expect_message(
+      plot_DoseResponseCurve(fit, reg_points_pch = 1),
+      "'reg_points_pch' should have length 3")
+  })
 
 test_that("plot output", {
   testthat::skip_on_cran()
@@ -31,17 +36,16 @@ test_that("plot output", {
 
   ## check plot settings
   expect_s4_class(plot_DoseResponseCurve(fit, legend = FALSE,
-                                         reg_points_pch = 1,
+                                         reg_points_pch = c(19, 1, 2),
                                          density_polygon = FALSE,
                                          box = FALSE), "RLum.Results")
   expect_message(plot_DoseResponseCurve(fit.extra.gok, log = "x"),
-                 "No logarithmic transformation allowed on a fit obtained with")
+                 "Logarithmic transformation not allowed on an object fitted with")
 })
 
 test_that("graphical snapshot tests", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
-  testthat::skip_if_not(getRversion() >= "4.4.0")
 
   SW({
   vdiffr::expect_doppelganger("default",
@@ -50,9 +54,10 @@ test_that("graphical snapshot tests", {
                               plot_DoseResponseCurve(fit, log = "xy"))
   vdiffr::expect_doppelganger("extrapolation-gok",
                               plot_DoseResponseCurve(fit.extra.gok))
+  vdiffr::expect_doppelganger("alternate",
+                              plot_DoseResponseCurve(fit.alt))
   vdiffr::expect_doppelganger("cex.global",
                               plot_DoseResponseCurve(fit, legend = FALSE,
-                                                     reg_points_pch = 1,
                                                      density_polygon_col = "azure",
                                                      cex = 2))
 
