@@ -11,13 +11,12 @@ test_that("input validation", {
                "'data' should be of class 'RLum.Results', 'data.frame' or 'matrix'")
   expect_error(plot_ViolinPlot(df, summary = 5),
                "'summary' should be of class 'character'")
-  expect_error(plot_ViolinPlot(df, summary.pos = list()),
-               "'summary.pos' should be of class 'numeric' or 'character'")
   expect_error(plot_ViolinPlot(df, summary.pos = 5),
                "'summary.pos' should have length 2")
+  expect_error(plot_ViolinPlot(df, summary.pos = list()),
+               "'summary.pos' should be one of 'sub', 'left', 'center', 'right'")
   expect_error(plot_ViolinPlot(df, summary.pos = "error"),
                "'summary.pos' should be one of 'sub', 'left', 'center', 'right'")
-
   expect_error(plot_ViolinPlot(data.frame(a = letters)),
                "All elements of 'data' should be of class 'numeric'")
   expect_error(plot_ViolinPlot(data.frame()),
@@ -55,7 +54,6 @@ test_that("check functionality", {
 test_that("graphical snapshot tests", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
-  testthat::skip_if_not(getRversion() >= "4.4.0")
 
   SW({
   vdiffr::expect_doppelganger("ViolinPlot defaults",
